@@ -76,7 +76,7 @@ SKGPredicatCreator::SKGPredicatCreator ( QWidget *parent, SKGDocument* document,
 
             foreach ( const QString& att, iListAtt )
             {
-                if(document) kAttributes->addItem ( document->getIcon ( att ), document->getDisplay ( att ), att );
+                if (document) kAttributes->addItem ( document->getIcon ( att ), document->getDisplay ( att ), att );
             }
         }
     }
@@ -115,8 +115,37 @@ SKGPredicatCreator::SKGPredicatCreator ( QWidget *parent, SKGDocument* document,
 
         if ( document )
         {
-            SKGMainPanel::fillWithDistinctValue ( cmbVal1, document, "v_operation_consolidated", attribute, "" );
-            SKGMainPanel::fillWithDistinctValue ( cmbVal2, document, "v_operation_consolidated", attribute, "" );
+            QString realTable="operation";
+            QString realAtt=attribute;
+            QString realCond="";
+            if ( attribute=="t_REALCATEGORY" )
+            {
+                realTable="category";
+                realAtt="t_fullname";
+            }
+            else if ( attribute=="t_ACCOUNT" )
+            {
+                realTable="account";
+                realAtt="t_name";
+            }
+            else if ( attribute=="t_REALREFUND" )
+            {
+                realTable="refund";
+                realAtt="t_name";
+            }
+            else if ( attribute=="t_PAYEE" )
+            {
+                realTable="payee";
+                realAtt="t_name";
+            }
+            else if (attribute.startsWith(QLatin1String("p_")))
+            {
+                realTable="parameters";
+                realAtt="t_value";
+                realCond="t_name='"+attribute.right(attribute.length()-2)+'\'';
+            }
+            SKGMainPanel::fillWithDistinctValue ( cmbVal1, document, realTable, realAtt, realCond );
+            SKGMainPanel::fillWithDistinctValue ( cmbVal2, document, realTable, realAtt, realCond );
         }
     }
     else  if ( attType==SKGServices::INTEGER || attType==SKGServices::FLOAT )
@@ -184,7 +213,7 @@ SKGPredicatCreator::SKGPredicatCreator ( QWidget *parent, SKGDocument* document,
     if ( kValue1 ) kValue1->installEventFilter ( this );
     if ( kValue2 ) kValue2->installEventFilter ( this );
     if ( kOperator ) kOperator->installEventFilter ( this );
-    if ( kAttributes ) kOperator->installEventFilter ( this );
+    if ( kAttributes ) kAttributes->installEventFilter ( this );
 
     QStringList listOps=SKGRuleObject::getListOfOperators ( attType, updateMode ? SKGRuleObject::UPDATE : SKGRuleObject::SEARCH );
     int nb=listOps.count();
@@ -193,9 +222,9 @@ SKGPredicatCreator::SKGPredicatCreator ( QWidget *parent, SKGDocument* document,
     {
         QString op=listOps.at ( i );
         QString nlsOp=SKGRuleObject::getDisplayForOperator ( op,
-							     i18nc ("Default value", "..." ),
-							     i18nc ("Default value", "..." ),
-							     i18nc ( "Noun, an item's attribute","attribute" ) );
+                      i18nc ("Default value", "..." ),
+                      i18nc ("Default value", "..." ),
+                      i18nc ( "Noun, an item's attribute","attribute" ) );
 
         kOperator->addItem ( nlsOp, op );
     }
