@@ -51,10 +51,17 @@
  */
 #define DUMPCATEGORY		(2<<13)
 
+/**
+ * @def DUMPPAYEE
+ * To display payees
+ * @see dump
+ */
+#define DUMPPAYEE		(2<<14)
+
 /**
  * @def DUMPBANKOBJECT
  * To display categories
  * @see dump
  */
-#define DUMPBANKOBJECT		DUMPUNIT|DUMPACCOUNT|DUMPOPERATION|DUMPCATEGORY
+#define DUMPBANKOBJECT		DUMPUNIT|DUMPACCOUNT|DUMPOPERATION|DUMPCATEGORY|DUMPPAYEE
 #endif
