@@ -27,7 +27,7 @@
 
 #include <klocale.h>
 
-SKGSubOperationObject::SKGSubOperationObject(const SKGDocument* iDocument, int iID): SKGObjectBase(iDocument, "v_suboperation", iID)
+SKGSubOperationObject::SKGSubOperationObject(SKGDocument* iDocument, int iID): SKGObjectBase(iDocument, "v_suboperation", iID)
 {
 }
 
@@ -36,84 +36,84 @@ SKGSubOperationObject::~SKGSubOperationObject()
 }
 
 SKGSubOperationObject::SKGSubOperationObject(const SKGSubOperationObject& iObject)
-                : SKGObjectBase(iObject)
+        : SKGObjectBase(iObject)
 {
 }
 
 SKGSubOperationObject::SKGSubOperationObject(const SKGObjectBase& iObject)
 {
-        if (iObject.getRealTable()=="suboperation") {
-                copyFrom(iObject);
-        } else {
-                *this=SKGObjectBase::SKGObjectBase(iObject.getDocument(), "v_suboperation", iObject.getID());
-        }
+    if (iObject.getRealTable()=="suboperation") {
+        copyFrom(iObject);
+    } else {
+        *this=SKGObjectBase(iObject.getDocument(), "v_suboperation", iObject.getID());
+    }
 }
 
 const SKGSubOperationObject& SKGSubOperationObject::operator= (const SKGObjectBase& iObject)
 {
-        copyFrom(iObject);
-        return *this;
+    copyFrom(iObject);
+    return *this;
 }
 
 SKGError SKGSubOperationObject::setComment(const QString& iComment)
 {
-        return setAttribute("t_comment", iComment);
+    return setAttribute("t_comment", iComment);
 }
 
 QString SKGSubOperationObject::getComment() const
 {
-        return getAttribute("t_comment");
+    return getAttribute("t_comment");
 }
 
 SKGError SKGSubOperationObject::getParentOperation(SKGOperationObject& oOperation) const
 {
-        SKGError err = getObject(getDocument(), "v_operation", "id=" + getAttribute("rd_operation_id"), oOperation);
-        return err;
+    SKGError err = getObject(getDocument(), "v_operation", "id=" + getAttribute("rd_operation_id"), oOperation);
+    return err;
 }
 
 SKGError SKGSubOperationObject::setParentOperation(const SKGOperationObject& iOperation)
 {
-        return setAttribute("rd_operation_id", SKGServices::intToString(iOperation.getID()));
+    return setAttribute("rd_operation_id", SKGServices::intToString(iOperation.getID()));
 }
 
 
 SKGError SKGSubOperationObject::getCategory(SKGCategoryObject& oCategory) const
 {
-        SKGError err = getObject(getDocument(), "v_category", "id=" + getAttribute("r_category_id"), oCategory);
-        return err;
+    SKGError err = getObject(getDocument(), "v_category", "id=" + getAttribute("r_category_id"), oCategory);
+    return err;
 }
 
 SKGError SKGSubOperationObject::setCategory(const SKGCategoryObject& iCategory)
 {
-        return setAttribute("r_category_id", SKGServices::intToString(iCategory.getID()));
+    return setAttribute("r_category_id", SKGServices::intToString(iCategory.getID()));
 }
 
 SKGError SKGSubOperationObject::setQuantity(double iValue)
 {
-        return setAttribute("f_value", SKGServices::doubleToString(iValue));
+    return setAttribute("f_value", SKGServices::doubleToString(iValue));
 }
 
 double SKGSubOperationObject::getQuantity() const
 {
-        return SKGServices::stringToDouble(getAttribute("f_value"));
+    return SKGServices::stringToDouble(getAttribute("f_value"));
 }
 
 
 SKGError SKGSubOperationObject::setTracker(const SKGTrackerObject& iTracker)
 {
-        SKGError err;
-        if (iTracker.isClosed()) {
-                err=SKGError(ERR_FAIL, i18nc("Error message", "Impossible to add an operation in a closed tracker"));
-        } else {
-                err=setAttribute("r_refund_id", SKGServices::intToString(iTracker.getID()));
-        }
-        return err;
+    SKGError err;
+    if (iTracker.isClosed()) {
+        err=SKGError(ERR_FAIL, i18nc("Error message", "Impossible to add an operation in a closed tracker"));
+    } else {
+        err=setAttribute("r_refund_id", SKGServices::intToString(iTracker.getID()));
+    }
+    return err;
 }
 
 SKGError SKGSubOperationObject::getTracker(SKGTrackerObject& oTracker) const
 {
-        SKGError err = getObject(getDocument(), "v_refund", "id=" + getAttribute("r_refund_id"), oTracker);
-        return err;
+    SKGError err = getObject(getDocument(), "v_refund", "id=" + getAttribute("r_refund_id"), oTracker);
+    return err;
 
 }
 
