@@ -47,7 +47,7 @@ int main ( int argc, char** argv )
         SKGUnitObject unit_euro ( &document1 );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_INIT", err );
 
             //Creation bank
@@ -76,9 +76,9 @@ int main ( int argc, char** argv )
 
         }
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_BP_QIF", err );
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/ref.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/ref.qif" );
             SKGTESTERROR ( "QIF.setDefaultAccount", imp1.setDefaultAccount ( &account ), true );
             SKGTESTERROR ( "QIF.setDefaultUnit", imp1.setDefaultUnit ( &unit_euro ), true );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
@@ -88,15 +88,14 @@ int main ( int argc, char** argv )
         SKGTEST ( "ACCOUNT:getCurrentAmount", SKGServices::doubleToString ( account.getCurrentAmount() ), "-935" );
 
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_BP_QIF", err );
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, "" );
+            SKGImportExportManager imp1 ( &document1, "" );
             SKGTESTERROR ( "QIF.cleanBankImport", imp1.cleanBankImport(), true );
-            SKGTESTERROR ( "QIF.cleanBankPerfectImport", imp1.cleanBankPerfectImport(), true );
             int out=0;
             SKGTESTERROR ( "QIF.findAndGroupTransfers", imp1.findAndGroupTransfers ( out ), true );
 
-            SKGImportExportManager exp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "OUT" ) +"/skgtestimportqif/ref.qif" );
+            SKGImportExportManager exp1 ( &document1, getTestPath ( "OUT" ) +"/skgtestimportqif/ref.qif" );
             SKGTESTERROR ( "QIF.exportFile", exp1.exportFile(), true );
         }
 
@@ -113,7 +112,7 @@ int main ( int argc, char** argv )
         SKGUnitObject unit_euro ( &document1 );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_INIT", err );
 
             //Creation bank
@@ -139,20 +138,19 @@ int main ( int argc, char** argv )
 
         }
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_BP_QIF", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/E0269787.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/E0269787.qif" );
             SKGTESTERROR ( "QIF.setDefaultAccount", imp1.setDefaultAccount ( &account ), true );
             SKGTESTERROR ( "QIF.setDefaultUnit", imp1.setDefaultUnit ( &unit_euro ), true );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
             SKGTESTERROR ( "QIF.cleanBankImport", imp1.cleanBankImport(), true );
-            SKGTESTERROR ( "QIF.cleanBankPerfectImport", imp1.cleanBankPerfectImport(), true );
             int out=0;
             SKGTESTERROR ( "QIF.findAndGroupTransfers", imp1.findAndGroupTransfers ( out ), true );
 
 
-            SKGImportExportManager exp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "OUT" ) +"/skgtestimportqif/E0269787.qif" );
+            SKGImportExportManager exp1 ( &document1, getTestPath ( "OUT" ) +"/skgtestimportqif/E0269787.qif" );
             SKGTESTERROR ( "QIF.exportFile", exp1.exportFile(), true );
         }
 
@@ -162,25 +160,23 @@ int main ( int argc, char** argv )
         //Check import with account retrieved from file
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         {
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "OUT" ) +"/skgtestimportqif/E0269787.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "OUT" ) +"/skgtestimportqif/E0269787.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
             SKGTESTERROR ( "QIF.cleanBankImport", imp1.cleanBankImport(), true );
-            SKGTESTERROR ( "QIF.cleanBankPerfectImport", imp1.cleanBankPerfectImport(), true );
             int out=0;
             SKGTESTERROR ( "QIF.findAndGroupTransfers", imp1.findAndGroupTransfers ( out ), true );
 
-            SKGImportExportManager exp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "OUT" ) +"/skgtestimportqif/E0269787_bis.qif" );
+            SKGImportExportManager exp1 ( &document1, getTestPath ( "OUT" ) +"/skgtestimportqif/E0269787_bis.qif" );
             SKGTESTERROR ( "QIF.exportFile", exp1.exportFile(), true );
         }
 
         //Check multi import
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         {
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "OUT" ) +"/skgtestimportqif/ref.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "OUT" ) +"/skgtestimportqif/ref.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );	//Double import
             SKGTESTERROR ( "QIF.cleanBankImport", imp1.cleanBankImport(), true );
-            SKGTESTERROR ( "QIF.cleanBankPerfectImport", imp1.cleanBankPerfectImport(), true );
             int out=0;
             SKGTESTERROR ( "QIF.findAndGroupTransfers", imp1.findAndGroupTransfers ( out ), true );
         }
@@ -188,26 +184,24 @@ int main ( int argc, char** argv )
         //Check import with account retrieved from files
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         {
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "OUT" ) +"/skgtestimportqif/ref.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "OUT" ) +"/skgtestimportqif/ref.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
-            SKGImportExportManager imp2 ( &document1, SKGImportExportManager::QIF, getTestPath ( "OUT" ) +"/skgtestimportqif/E0269787.qif" );
+            SKGImportExportManager imp2 ( &document1, getTestPath ( "OUT" ) +"/skgtestimportqif/E0269787.qif" );
             SKGTESTERROR ( "QIF.importFile", imp2.importFile(), true );
             SKGTESTERROR ( "QIF.cleanBankImport", imp1.cleanBankImport(), true );
-            SKGTESTERROR ( "QIF.cleanBankPerfectImport", imp1.cleanBankPerfectImport(), true );
             int out=0;
             SKGTESTERROR ( "QIF.findAndGroupTransfers", imp1.findAndGroupTransfers ( out ), true );
 
-            SKGImportExportManager exp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "OUT" ) +"/skgtestimportqif/E0269787_ref.qif" );
+            SKGImportExportManager exp1 ( &document1, getTestPath ( "OUT" ) +"/skgtestimportqif/E0269787_ref.qif" );
             SKGTESTERROR ( "QIF.exportFile", exp1.exportFile(), true );
         }
 
         //Check import qif multi accounts
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         {
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "OUT" ) +"/skgtestimportqif/E0269787_ref.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "OUT" ) +"/skgtestimportqif/E0269787_ref.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
             SKGTESTERROR ( "QIF.cleanBankImport", imp1.cleanBankImport(), true );
-            SKGTESTERROR ( "QIF.cleanBankPerfectImport", imp1.cleanBankPerfectImport(), true );
             int out=0;
             SKGTESTERROR ( "QIF.findAndGroupTransfers", imp1.findAndGroupTransfers ( out ), true );
             QStringList oResult;
@@ -226,7 +220,7 @@ int main ( int argc, char** argv )
         SKGUnitObject unit_euro ( &document1 );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_INIT", err );
 
             //Creation bank
@@ -252,20 +246,19 @@ int main ( int argc, char** argv )
 
         }
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_ING_QIF", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/ing.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/ing.qif" );
             SKGTESTERROR ( "QIF.setDefaultAccount", imp1.setDefaultAccount ( &account ), true );
             SKGTESTERROR ( "QIF.setDefaultUnit", imp1.setDefaultUnit ( &unit_euro ), true );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
             SKGTESTERROR ( "QIF.cleanBankImport", imp1.cleanBankImport(), true );
-            SKGTESTERROR ( "QIF.cleanBankPerfectImport", imp1.cleanBankPerfectImport(), true );
             int out=0;
             SKGTESTERROR ( "QIF.findAndGroupTransfers", imp1.findAndGroupTransfers ( out ), true );
 
 
-            SKGImportExportManager exp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "OUT" ) +"/skgtestimportqif/ing.qif" );
+            SKGImportExportManager exp1 ( &document1, getTestPath ( "OUT" ) +"/skgtestimportqif/ing.qif" );
             SKGTESTERROR ( "QIF.exportFile", exp1.exportFile(), true );
         }
     }
@@ -276,10 +269,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_ING_QIF", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/moto.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/moto.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
 
@@ -298,17 +291,19 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_INIT", err );
 
             SKGUnitObject unit;
-            SKGTESTERROR ( "FRANC.setName",SKGUnitObject::createCurrencyUnit ( &document1, "FRF", unit ), true );
+            SKGTESTERROR ( "SKGUnitObject::createCurrencyUnit",SKGUnitObject::createCurrencyUnit ( &document1, "EUR", unit ), true );
+            SKGTESTERROR ( "SKGUnitObject::createCurrencyUnit",SKGUnitObject::createCurrencyUnit ( &document1, "FRF", unit ), true );
+            SKGTESTERROR ( "FRANC.addOrModifyUnitValue",document1.addOrModifyUnitValue ("French Franc (FRF)", QDate(1963,1,1), 1.0/6.55957), true );
         }
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_ING_QIF", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/moto.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/moto.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
 
             document1.dump ( DUMPBANKOBJECT );
@@ -329,10 +324,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_KMM_QIF", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/kmm-without-category.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/kmm-without-category.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
 
@@ -350,10 +345,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_KMM_QIF", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/kmm-with-category.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/kmm-with-category.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
 
@@ -371,17 +366,17 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_REMI_QIF", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/remi_2.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/remi_2.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_REMI_QIF", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/remi_2.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/remi_2.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
         {
@@ -398,10 +393,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_DOUBLE", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/double.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/double.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
         {
@@ -418,10 +413,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/350286.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/350286.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
 
@@ -439,10 +434,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/393596.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/393596.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
 
@@ -460,10 +455,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/503166.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/503166.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
 
@@ -481,10 +476,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/392707.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/392707.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
 
@@ -502,10 +497,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/373584.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/373584.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
 
@@ -523,10 +518,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/199818.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/199818.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
 
@@ -544,10 +539,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/201316.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/201316.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
 
@@ -571,10 +566,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/201451.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/201451.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
 
@@ -592,10 +587,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/BNP_CC_virement.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/BNP_CC_virement.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
         }
 
@@ -619,13 +614,13 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/Fortuneo PEA (Caisse).qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/Fortuneo PEA (Caisse).qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
 
-            SKGImportExportManager imp2 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/Fortuneo PEA.qif" );
+            SKGImportExportManager imp2 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/Fortuneo PEA.qif" );
             SKGTESTERROR ( "QIF.importFile", imp2.importFile(), true );
         }
 
@@ -661,13 +656,13 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/Cortal PEA.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/Cortal PEA.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
 
-            SKGImportExportManager imp2 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/EADS.qif" );
+            SKGImportExportManager imp2 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/EADS.qif" );
             SKGTESTERROR ( "QIF.importFile", imp2.importFile(), true );
         }
     }
@@ -678,10 +673,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/216520.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/216520.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
 
         }
@@ -699,20 +694,20 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT_INIT", err );
 
             SKGUnitObject unit;
             SKGTESTERROR ( "EUR.setName",SKGUnitObject::createCurrencyUnit ( &document1, "Euro (EUR)", unit ), true );
         }
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/exp_inv.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/exp_inv.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
 
-            SKGImportExportManager exp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "OUT" ) +"/skgtestimportqif/exp_inv.qif" );
+            SKGImportExportManager exp1 ( &document1, getTestPath ( "OUT" ) +"/skgtestimportqif/exp_inv.qif" );
             SKGTESTERROR ( "QIF.exportFile", exp1.exportFile(), true );
         }
     }
@@ -723,10 +718,10 @@ int main ( int argc, char** argv )
         SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
         SKGError err;
         {
-            //Scrope of the transaction
+            //Scope of the transaction
             SKGBEGINTRANSACTION ( document1, "IMPORT", err );
 
-            SKGImportExportManager imp1 ( &document1, SKGImportExportManager::QIF, getTestPath ( "IN" ) +"/skgtestimportqif/t2.qif" );
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/t2.qif" );
             SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
 
         }
@@ -744,6 +739,21 @@ int main ( int argc, char** argv )
         }
     }
 
+    {
+        //233930
+        SKGDocumentBank document1;
+        SKGTESTERROR ( "document1.initialize()", document1.initialize(), true );
+        SKGError err;
+        {
+            //Scope of the transaction
+            SKGBEGINTRANSACTION ( document1, "IMPORT", err );
+
+            SKGImportExportManager imp1 ( &document1, getTestPath ( "IN" ) +"/skgtestimportqif/233930.qif" );
+            SKGTESTERROR ( "QIF.importFile", imp1.importFile(), true );
+
+        }
+    }
+
     //End test
     SKGENDTEST();
 }
