@@ -88,11 +88,16 @@ QString SKGInterfacePlugin::statusTip () const
     return toolTip();
 }
 
-QString SKGInterfacePlugin::toolTip () const
+QString SKGInterfacePlugin::icon () const
 {
     return "";
 }
 
+QString SKGInterfacePlugin::toolTip () const
+{
+    return title();
+}
+
 QStringList SKGInterfacePlugin::tips() const
 {
     return QStringList();
@@ -103,11 +108,6 @@ bool SKGInterfacePlugin::isInContext() const
     return false;
 }
 
-bool SKGInterfacePlugin::isTabClosable() const
-{
-    return false;
-}
-
 bool SKGInterfacePlugin::isEnabled() const
 {
     return true;
