@@ -59,7 +59,7 @@ public:
                             SUM       =0x1,
                             AVERAGE   =0x2,
                             LIMITS    =0x4,
-			    ALL       =255
+                            ALL       =255
                            };
     /**
      * Graph type
@@ -138,7 +138,7 @@ public:
                            SKGServices::SKGUnitInfo iPrimaryUnit,
                            SKGServices::SKGUnitInfo iSecondaryUnit,
                            DisplayAdditionalFlag iAdditionalInformation=SKGTableWithGraph::ALL,
-			   int iNbVirtualColumn=0);
+                           int iNbVirtualColumn=0);
 
     /**
      * Get the mode for the additional display
@@ -168,7 +168,7 @@ public:
      * Set the visibility of the graph
      * @param iVisible the visibility
      */
-    virtual void setGraphVisible ( bool iVisible ) const;
+    virtual void setGraphVisible ( bool iVisible );
 
     /**
      * Get athe visibility of the graph
@@ -264,7 +264,10 @@ private slots:
     void onSwitchToolBarVisibility();
     void onSwitchLimits();
     void onSwitchLinearRegression();
+    void onSwitchLegend();
     void onFilterModified();
+    void onChangeColor();
+    void onResetColors();
     void refresh();
     void redrawGraph();
     void redrawGraphDelayed();
@@ -274,6 +277,7 @@ private:
 
     double computeStepSize ( double iRange, double iTargetSteps );
     void addArrow ( const QPointF& iPeak, double iSize, double iArrowAngle=45, double iDegree=90 );
+    void addLegend ( const QPointF& iPosition, double iSize, double iScaleText, double iMaxY );
     int getAverageColumnIndex() const;
     int getMinColumnIndex() const;
 
@@ -294,6 +298,7 @@ private:
     bool toolBarVisible;
     bool limitVisible;
     bool linearRegressionVisible;
+    bool legendVisible;
 
     KMenu* mainMenu;
     QTimer* timer;
@@ -301,13 +306,15 @@ private:
     QAction* actShowToolBar;
     QAction* actShowLimits;
     QAction* actShowLinearRegression;
+    QAction* actShowLegend;
 
     int indexSum;
     int indexAverage;
     int indexMin;
     int indexLinearRegression;
+    QMap<QString, QColor> mapTitleColor;
 };
 
- Q_DECLARE_OPERATORS_FOR_FLAGS(SKGTableWithGraph::DisplayAdditionalFlag)
+Q_DECLARE_OPERATORS_FOR_FLAGS(SKGTableWithGraph::DisplayAdditionalFlag)
 
 #endif // SKGTABLEWITHGRAPH_H
