@@ -32,6 +32,7 @@
 #include <QBasicTimer>
 
 #include <kmenu.h>
+#include "skgmainpanel.h"
 
 class SKGDocument;
 class QTimer;
@@ -46,14 +47,14 @@ class SKGBASEGUI_EXPORT SKGTreeView : public QTreeView
      * State of the view
      */
     Q_PROPERTY ( QString state READ getState WRITE setState USER true )
+    /**
+     * Text resizable by CTRL+wheel
+     */
+    Q_PROPERTY ( bool textResizable READ isTextResizable WRITE setTextResizable )
     /**
      * Auto resize mode of the view
      */
     Q_PROPERTY ( bool autoResized READ isAutoResized )
-    /**
-     * Smooth scrolling mode of the view
-     */
-    Q_PROPERTY ( bool smoothScrolling READ isSmoothScrolling )
 
 public:
     /**
@@ -86,17 +87,12 @@ public:
      */
     virtual bool isAutoResized();
 
-    /**
-     * To know if the smoothscrolling mode is enable
-     */
-    virtual bool isSmoothScrolling();
-
     /**
     * Set parameter to activate and save default state of this table
     * @param iDocument document pointer
     * @param iParameterName parameter name in this document
     */
-    virtual void setDefaultSaveParameters ( const SKGDocument* iDocument, const QString& iParameterName );
+    virtual void setDefaultSaveParameters ( SKGDocument* iDocument, const QString& iParameterName );
 
     /**
      * Get the table content
@@ -122,6 +118,13 @@ public:
      */
     virtual void setSelectionModel ( QItemSelectionModel * selectionModel );
 
+    /**
+     * Insert a registed action
+     * @see SKGMainPanel::registedGlobalAction
+     * @param iRegisteredAction the registed action. "" means separator
+     */
+    virtual void insertGlobalAction(const QString& iRegisteredAction="");
+
 signals:
     /**
      * Emitted when the empty area
@@ -133,6 +136,12 @@ signals:
      */
     void selectionChangedDelayed();
 
+    /**
+     * Emitted when zoom changed
+     * @param iZoomPosition zoom position (-10<=zoom position<=10)
+     */
+    void zoomChanged(int iZoomPosition);
+
 protected:
 
     /**
@@ -143,6 +152,29 @@ protected:
     virtual void mousePressEvent ( QMouseEvent * event );
 
 public slots:
+    /**
+     * This property holds whether to autorize text size modification by CTRL+wheel.
+     * @param resizable true of false
+     */
+    virtual void setTextResizable ( bool resizable );
+
+    /**
+     * Get the property to know if text is resizable
+     * @return the property
+     */
+    virtual bool isTextResizable () const;
+
+    /**
+     * Set the zoom position.
+     * @param iZoomPosition zoom position (-10<=zoom position<=10)
+     */
+    virtual void setZoomPosition ( int iZoomPosition );
+
+    /**
+     * Get zoom position
+     * @return zoom position (-10<=zoom position<=10)
+     */
+    virtual int zoomPosition () const;
 
     /**
      * Save the selection
@@ -178,11 +210,6 @@ public slots:
      */
     virtual void setAlternatingRowColors ( bool enable );
 
-    /**
-     * Swith the smooth Scrolling mode
-     */
-    virtual void switchSmoothScrolling();
-
     /**
      * Reset columns order
      */
@@ -198,6 +225,7 @@ public slots:
      */
     virtual void resizeColumnsToContentsDelayed();
 
+
 protected:
     /**
       * Event filtering
@@ -229,13 +257,9 @@ private slots:
 private:
     Q_DISABLE_COPY ( SKGTreeView );
 
-    void timerEvent ( QTimerEvent *event );
-
     KMenu* header_menu;
     bool autoResize;
     QAction* actAutoResize;
-    bool smoothScrolling;
-    QAction* actSmoothScrolling;
     SKGDocument* document;
     QString parameterName;
     QStringList selection;
@@ -252,6 +276,9 @@ private:
     QTimer* timerDelayedResize;
     QTimer* timerSelectionChanged;
     QTimer* timerScrollSelection;
+    bool textResizable;
+    int fontOriginalPointSize;
+    int iconOriginalSize;
 };
 
 #endif // SKGTREEVIEW_H
