@@ -24,13 +24,15 @@
 #include "skgmainpanel.h"
 #include "skgobjectmodel.h"
 #include "skgtransactionmng.h"
+#include "skgunitobject.h"
+#include "skgunitvalueobject.h"
 #include "skgbankobject.h"
-#include "skgaccountobject.h"
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
+#include <kfiledialog.h>
 
 #include <QDomDocument>
 #include <QFile>
@@ -43,6 +45,7 @@ SKGBankPluginWidget::SKGBankPluginWidget ( SKGDocumentBank* iDocument )
     SKGTRACEIN ( 10, "SKGBankPluginWidget::SKGBankPluginWidget" );
 
     ui.setupUi ( this );
+    ui.kUnitEdit->setDocument(iDocument);
 
     timer = new QTimer ( this );
     timer->setSingleShot ( true );
@@ -63,7 +66,7 @@ SKGBankPluginWidget::SKGBankPluginWidget ( SKGDocumentBank* iDocument )
     ui.kAccountCreatorType->addItem ( i18nc ( "Noun, a type of account", "Other" ) );
 
     //Bind account creation view
-    objectModel = new SKGObjectModel ( ( SKGDocumentBank* ) getDocument(), "v_account_display", "1=0", this, "", false );
+    objectModel = new SKGObjectModel ( static_cast<SKGDocumentBank*>(getDocument()), "v_account_display", "1=0", this, "", false );
     SKGSortFilterProxyModel* modelProxy = new SKGSortFilterProxyModel ( this );
     modelProxy->setSourceModel ( objectModel );
     modelProxy->setSortRole ( Qt::UserRole );
@@ -76,20 +79,13 @@ SKGBankPluginWidget::SKGBankPluginWidget ( SKGDocumentBank* iDocument )
     //Add registered global action in contextual menu
     if ( SKGMainPanel::getMainPanel() )
     {
-        ui.kAccountTableViewEdition->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "edit_delete" ) );
-        {
-            QAction* sep=new QAction ( this );
-            sep->setSeparator ( true );
-            ui.kAccountTableViewEdition->insertAction ( 0, sep );
-        }
-        ui.kAccountTableViewEdition->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "edit_switch_highlight" ) );
-        ui.kAccountTableViewEdition->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "edit_reconciliate" ) );
-        {
-            QAction* sep=new QAction ( this );
-            sep->setSeparator ( true );
-            ui.kAccountTableViewEdition->insertAction ( 0, sep );
-        }
-        ui.kAccountTableViewEdition->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "open_report" ) );
+        ui.kAccountTableViewEdition->insertGlobalAction ( "edit_delete" );
+        ui.kAccountTableViewEdition->insertGlobalAction ();
+        ui.kAccountTableViewEdition->insertGlobalAction ( "edit_switch_highlight" );
+        ui.kAccountTableViewEdition->insertGlobalAction ( "edit_reconciliate" );
+        ui.kAccountTableViewEdition->insertGlobalAction ();
+        ui.kAccountTableViewEdition->insertGlobalAction ( "edit_find" );
+        ui.kAccountTableViewEdition->insertGlobalAction ( "open_report" );
     }
     connect ( ui.kAccountTableViewEdition, SIGNAL ( selectionChangedDelayed() ), this, SLOT ( onSelectionChanged() ) );
     connect ( objectModel, SIGNAL ( beforeReset() ), ui.kAccountTableViewEdition, SLOT ( saveSelection() ) );
@@ -129,6 +125,7 @@ SKGBankPluginWidget::SKGBankPluginWidget ( SKGDocumentBank* iDocument )
                 ui.kAccountCreatorIcon->addItem ( QIcon ( dirLogo.absoluteFilePath ( line ) ), bankName );
             }
         }
+        ui.kAccountCreatorIcon->addItem ( i18nc("Other type of bank account","Other...") );
 
         file.close();
     }
@@ -153,20 +150,20 @@ SKGBankPluginWidget::~SKGBankPluginWidget()
 
 bool SKGBankPluginWidget::eventFilter ( QObject *object, QEvent *event )
 {
-    if ( event && event->type() == QEvent::KeyPress  )
+    if ( event && event->type() == QEvent::KeyPress )
     {
-      QKeyEvent *keyEvent = ( QKeyEvent * ) event;
-      if ( (keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && object==this)
-      {
-	if ( QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAccountCreatorAdd->isEnabled())
-	{
-	    ui.kAccountCreatorAdd->click();
-	}
-	else if ( QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kAccountCreatorUpdate->isEnabled())
-	{
-	    ui.kAccountCreatorUpdate->click();
-	}
-      }
+        QKeyEvent *keyEvent = ( QKeyEvent * ) event;
+        if ( ( keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter ) && object==this )
+        {
+            if ( QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAccountCreatorAdd->isEnabled() )
+            {
+                ui.kAccountCreatorAdd->click();
+            }
+            else if ( QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kAccountCreatorUpdate->isEnabled() )
+            {
+                ui.kAccountCreatorUpdate->click();
+            }
+        }
     }
 
     return false;
@@ -191,7 +188,8 @@ void SKGBankPluginWidget::onSelectionChanged()
             SKGAccountObject account ( objectModel->getObject ( idxs ) );
             SKGBankObject bank;
             account.getBank ( bank );
-            QString iconName=bank.getIcon();
+            QString fileName=bank.getIcon();
+            QString iconName=fileName;
             if ( iconName.length() )
             {
                 iconName.remove ( ".png" );
@@ -202,7 +200,16 @@ void SKGBankPluginWidget::onSelectionChanged()
                 {
                     iconName=rx.cap ( 1 );
                 }
-                ui.kAccountCreatorIcon->setText ( iconName );
+                if (ui.kAccountCreatorIcon->contains(iconName)) ui.kAccountCreatorIcon->setText ( iconName );
+                else if (ui.kAccountCreatorIcon->contains(fileName)) ui.kAccountCreatorIcon->setText ( fileName );
+                else
+                {
+                    int c=ui.kAccountCreatorIcon->count()-1;
+                    bool b=ui.kAccountCreatorIcon->blockSignals(true);
+                    ui.kAccountCreatorIcon->insertItem (c, QIcon ( fileName ), fileName );
+                    ui.kAccountCreatorIcon->setCurrentIndex(c);
+                    ui.kAccountCreatorIcon->blockSignals(b);
+                }
             }
             else ui.kAccountCreatorIcon->setText ( "" );
 
@@ -214,6 +221,13 @@ void SKGBankPluginWidget::onSelectionChanged()
             ui.kAccountCreatorType->setText ( account.getAttribute ( "t_TYPENLS" ) );
             ui.kAccountCreatorAddress->setText ( account.getAttribute ( "t_agency_address" ) );
             ui.kAccountCreatorComment->setText ( account.getAttribute ( "t_comment" ) );
+
+            double oBalance=0;
+            SKGUnitObject oUnit;
+            account.getInitialBalance ( oBalance, oUnit );
+
+            ui.kAmountEdit->setText ( KGlobal::locale()->formatMoney (oBalance, "", 2) );
+            ui.kUnitEdit->setUnit ( oUnit );
         }
 
         onAccountCreatorModified();
@@ -255,18 +269,47 @@ void SKGBankPluginWidget::setCurrentMode ( int iMode )
     onAccountCreatorModified();
 }
 
+void SKGBankPluginWidget::onIconChanged()
+{
+    SKGTRACEIN ( 10, "SKGBankPluginWidget::onIconChanged" );
+
+    int c=ui.kAccountCreatorIcon->currentIndex();
+    if (c && c==ui.kAccountCreatorIcon->count()-1)
+    {
+        QString fileName=KFileDialog::getOpenFileName ( KUrl ( "kfiledialog:///IMPEXP" ), "image/png image/jpeg image/gif image/tiff" , this );
+        if ( !fileName.isEmpty() )
+        {
+            if (ui.kAccountCreatorIcon->contains(fileName)) ui.kAccountCreatorIcon->setText ( fileName );
+            else
+            {
+                bool b=ui.kAccountCreatorIcon->blockSignals(true);
+                ui.kAccountCreatorIcon->insertItem (c, QIcon ( fileName ), fileName );
+                ui.kAccountCreatorIcon->setCurrentIndex(c);
+                ui.kAccountCreatorIcon->blockSignals(b);
+            }
+        } else ui.kAccountCreatorIcon->setCurrentIndex(c-1);
+    }
+
+    onAccountCreatorModified();
+}
+
+
 void SKGBankPluginWidget::onAccountCreatorModified()
 {
     SKGTRACEIN ( 10, "SKGBankPluginWidget::onAccountCreatorModified" );
 
-    bool activated=ui.kAccountCreatorBank->text().length() >0 &&
-                   ui.kAccountCreatorAccount->text().length() >0;
+    bool activated=mode!=-1 &&
+                   ui.kAccountCreatorBank->text().length() >0 &&
+                   ui.kAccountCreatorAccount->text().length() >0 &&
+                   ui.kUnitEdit->currentText().length() >0;
 
     int nbSelect=getNbSelectedObjects();
     ui.kAccountCreatorAdd->setEnabled ( activated );
     ui.kAccountCreatorUpdate->setEnabled ( activated && nbSelect>0 );
     ui.kAccountCreatorAccount->setEnabled ( nbSelect<=1 );
     ui.kAccountCreatorNumber->setEnabled ( nbSelect<=1 );
+    ui.kAmountEdit->setEnabled ( nbSelect<=1 );
+    ui.kUnitEdit->setEnabled ( nbSelect<=1 );
 
     //Facilitate bank name
     if ( ui.kAccountCreatorBank->text().length() ==0 )
@@ -282,6 +325,11 @@ void SKGBankPluginWidget::onAccountCreatorModified()
     }
 }
 
+SKGError SKGBankPluginWidget::setInitialBalanceFromEditor(SKGAccountObject& iAccount)
+{
+    return iAccount.setInitialBalance(ui.kAmountEdit->value(), ui.kUnitEdit->getUnit());
+}
+
 void SKGBankPluginWidget::onAddAccountClicked()
 {
     SKGError err;
@@ -294,7 +342,7 @@ void SKGBankPluginWidget::onAddAccountClicked()
         QString accountname=ui.kAccountCreatorAccount->text();
         QString name=bankname+'-'+accountname;
         {
-            SKGBEGINTRANSACTION ( *getDocument(), i18nc("Noun, name of the user action", "Account creation [%1]", name ), err );
+            SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Account creation '%1'", name ), err );
 
             //Create bank object in case of missing
             SKGBankObject bankObj ( getDocument() );
@@ -302,11 +350,10 @@ void SKGBankPluginWidget::onAddAccountClicked()
             if ( err.isSucceeded() )
             {
                 //Build icon name
-                QString icon;
+                QString icon=ui.kAccountCreatorIcon->currentText();
                 int pos=ui.kAccountCreatorIcon->currentIndex();
-                if ( pos!=0 )
+                if ( pos!=0 && pos-1<listBankNumbers.count())
                 {
-                    icon=ui.kAccountCreatorIcon->currentText();
                     if ( listBankNumbers[pos-1].length() ) icon+="  "+listBankNumbers[pos-1];
 
                     icon.replace ( ' ', '_' );
@@ -330,15 +377,17 @@ void SKGBankPluginWidget::onAddAccountClicked()
             if ( err.isSucceeded() ) err=accountObj.setNumber ( ui.kAccountCreatorNumber->text() );
             if ( err.isSucceeded() ) err=accountObj.setType ( ( SKGAccountObject::AccountType ) ( ui.kAccountCreatorType->currentIndex() ) );
             if ( err.isSucceeded() ) err=accountObj.save ( false );
+            if ( err.isSucceeded() ) err=setInitialBalanceFromEditor(accountObj);
+            if ( err.isSucceeded() ) err=accountObj.save ( );
         }
 
         //status bar
         if ( err.isSucceeded() )
         {
-            err=SKGError(0, i18nc("Successful message after an user action", "Account [%1] created", name ) );
+            err=SKGError ( 0, i18nc ( "Successful message after an user action", "Account '%1' created", name ) );
             ui.kAccountTableViewEdition->selectObject ( accountObj.getUniqueID() );
         }
-        else err.addError ( ERR_FAIL, i18nc("Error message",  "Account creation failed" ) );
+        else err.addError ( ERR_FAIL, i18nc ( "Error message",  "Account creation failed" ) );
     }
     QApplication::restoreOverrideCursor();
 
@@ -366,7 +415,7 @@ void SKGBankPluginWidget::onModifyAccountClicked()
         SKGObjectBase::SKGListSKGObjectBase selection=getSelectedObjects();
 
         int nb=selection.count();
-        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Account update" ), err, nb );
+        SKGBEGINPROGRESSTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Account update" ), err, nb );
         for ( int i=0; err.isSucceeded() && i<nb; ++i )
         {
             SKGAccountObject accountObj=selection[i];
@@ -376,12 +425,14 @@ void SKGBankPluginWidget::onModifyAccountClicked()
             {
                 err=accountObj.setName ( ui.kAccountCreatorAccount->text() );
                 if ( err.isSucceeded() ) err=accountObj.setNumber ( ui.kAccountCreatorNumber->text() );
+                if ( err.isSucceeded() ) err=setInitialBalanceFromEditor(accountObj);
             }
             if ( err.isSucceeded() ) err=accountObj.setType ( ( SKGAccountObject::AccountType ) ( ui.kAccountCreatorType->currentIndex() ) );
             if ( err.isSucceeded() ) err=accountObj.setAgencyNumber ( ui.kAccountCreatorAgencyNumber->text() );
             if ( err.isSucceeded() ) err=accountObj.setAgencyAddress ( ui.kAccountCreatorAddress->text() );
             if ( err.isSucceeded() ) err=accountObj.setComment ( ui.kAccountCreatorComment->text() );
             if ( err.isSucceeded() ) err=accountObj.save();
+            if ( err.isSucceeded() ) err=accountObj.save();
 
             //Update bank
             SKGBankObject bankObj;
@@ -393,46 +444,45 @@ void SKGBankPluginWidget::onModifyAccountClicked()
             }
             else
             {
-		//The bank does not exist
-		int code=KMessageBox::Yes;
-		SKGBankObject currentBank;
-		err=accountObj.getBank(currentBank);
-		if(err.isSucceeded())
-		{
-		  SKGObjectBase::SKGListSKGObjectBase accounts;
-		  err=currentBank.getAccounts(accounts);
-		  if(err.isSucceeded() && accounts.count()>1)
-		  {
-		    QApplication::setOverrideCursor ( QCursor ( Qt::ArrowCursor ) );
-		    code=KMessageBox::questionYesNo ( this, i18nc("Question", "You are trying to modify bank name of account named \"%1\".\nDo you want to do this modification for all accounts of this bank ?",  accountObj.getName()));
-		    QApplication::restoreOverrideCursor();
-		  }
-		}
+                //The bank does not exist
+                int code=KMessageBox::Yes;
+                SKGBankObject currentBank;
+                err=accountObj.getBank ( currentBank );
+                if ( err.isSucceeded() )
+                {
+                    SKGObjectBase::SKGListSKGObjectBase accounts;
+                    err=currentBank.getAccounts ( accounts );
+                    if ( err.isSucceeded() && accounts.count() >1 )
+                    {
+                        QApplication::setOverrideCursor ( QCursor ( Qt::ArrowCursor ) );
+                        code=KMessageBox::questionYesNo ( this, i18nc ( "Question", "You are trying to modify bank name of account named \"%1\".\nDo you want to do this modification for all accounts of this bank ?",  accountObj.getName() ) );
+                        QApplication::restoreOverrideCursor();
+                    }
+                }
 
-		if(code==KMessageBox::Yes)
-		{
-		  //The bank does not exist ==> update this one
-		  if ( err.isSucceeded() ) err=accountObj.getBank ( bankObj );
-		  if ( err.isSucceeded() ) err=bankObj.setName ( ui.kAccountCreatorBank->text() );
-		}
-		else
-		{
-		  //The bank does not exist ==> create a new one
-		  bankObj=SKGBankObject(getDocument());
-		  if ( err.isSucceeded() ) err=bankObj.setName ( ui.kAccountCreatorBank->text() );
-		  if ( err.isSucceeded() ) err=bankObj.save();
-		  if ( err.isSucceeded() ) err=accountObj.setBank ( bankObj );
-		  if ( err.isSucceeded() ) err=accountObj.save();
-		}
+                if ( code==KMessageBox::Yes )
+                {
+                    //The bank does not exist ==> update this one
+                    if ( err.isSucceeded() ) err=accountObj.getBank ( bankObj );
+                    if ( err.isSucceeded() ) err=bankObj.setName ( ui.kAccountCreatorBank->text() );
+                }
+                else
+                {
+                    //The bank does not exist ==> create a new one
+                    bankObj=SKGBankObject ( getDocument() );
+                    if ( err.isSucceeded() ) err=bankObj.setName ( ui.kAccountCreatorBank->text() );
+                    if ( err.isSucceeded() ) err=bankObj.save();
+                    if ( err.isSucceeded() ) err=accountObj.setBank ( bankObj );
+                    if ( err.isSucceeded() ) err=accountObj.save();
+                }
             }
             if ( err.isSucceeded() )
             {
                 //Build icon name
-                QString icon;
+                QString icon=ui.kAccountCreatorIcon->currentText();
                 int pos=ui.kAccountCreatorIcon->currentIndex();
-                if ( pos!=0 )
+                if ( pos!=0 && pos-1<listBankNumbers.count())
                 {
-                    icon=ui.kAccountCreatorIcon->currentText();
                     if ( listBankNumbers[pos-1].length() ) icon+="  "+listBankNumbers[pos-1];
 
                     icon.replace ( ' ', '_' );
@@ -448,15 +498,15 @@ void SKGBankPluginWidget::onModifyAccountClicked()
             if ( err.isSucceeded() ) err=getDocument()->stepForward ( i+1 );
         }
 
-	//Remove bank without account
-	if(err.isSucceeded())
-	{
-	  err=SKGServices::executeSqliteOrder(getDocument(), "DELETE FROM bank WHERE (SELECT count(1) FROM account WHERE account.rd_bank_id=bank.id)=0");
-	}
+        //Remove bank without account
+        if ( err.isSucceeded() )
+        {
+            err=SKGServices::executeSqliteOrder ( getDocument(), "DELETE FROM bank WHERE NOT EXISTS(SELECT 1 FROM account WHERE account.rd_bank_id=bank.id)" );
+        }
 
         //status bar
-        if ( err.isSucceeded() ) err=SKGError(0, i18nc("Successful message after an user action", "Account updated." ) );
-        else err.addError ( ERR_FAIL, i18nc("Error message",  "Update failed" ) );
+        if ( err.isSucceeded() ) err=SKGError ( 0, i18nc ( "Successful message after an user action", "Account updated." ) );
+        else err.addError ( ERR_FAIL, i18nc ( "Error message",  "Update failed" ) );
     }
     QApplication::restoreOverrideCursor();
 
@@ -486,7 +536,7 @@ void SKGBankPluginWidget::onDoubleClickedAccount()
         }
 
         root.setAttribute ( "account", accountObj.getName() );
-        SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
+        SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
 
     }
     QApplication::restoreOverrideCursor();
@@ -612,7 +662,7 @@ void SKGBankPluginWidget::dataModified ( const QString& iTableName, int iIdTrans
     if ( db!=NULL && ( iTableName=="account" || iTableName.isEmpty() ) )
     {
         //Correction bug 2299394 vvv
-        if ( ui.kAccountTableViewEdition->isAutoResized() ) ui.kAccountTableViewEdition->resizeColumnsToContents();
+        if ( ui.kAccountTableViewEdition->isAutoResized() ) ui.kAccountTableViewEdition->resizeColumnsToContentsDelayed();
         //Correction bug 2299394 ^^^
 
         //Correction 215658: vvv because the table is modified, the selection is modified
@@ -635,27 +685,27 @@ void SKGBankPluginWidget::refreshInfoZone()
                                             listTmp );
     if ( listTmp.count() ==2 )
     {
-        SKGDocumentBank* doc= ( SKGDocumentBank* ) getDocument();
-	if(doc)
-	{
-	    SKGServices::SKGUnitInfo primary=doc->getPrimaryUnit();
-	    double v1=SKGServices::stringToDouble ( listTmp.at ( 1 ).at ( 0 ) );
-	    double v2=SKGServices::stringToDouble ( listTmp.at ( 1 ).at ( 1 ) );
-	    double v3=SKGServices::stringToDouble ( listTmp.at ( 1 ).at ( 2 ) );
-	    QString s1=doc->formatMoney ( v1, primary );
-	    QString s2=doc->formatMoney ( v2, primary );
-	    QString s3=doc->formatMoney ( v3, primary );
-	    ui.kInfo->setText ( i18nc ("Message", "Balance: %1     Cleared: %2     In Transit: %3", s1, s2, s3 ) );
+        SKGDocumentBank* doc= static_cast<SKGDocumentBank*>(getDocument());
+        if ( doc )
+        {
+            SKGServices::SKGUnitInfo primary=doc->getPrimaryUnit();
+            double v1=SKGServices::stringToDouble ( listTmp.at ( 1 ).at ( 0 ) );
+            double v2=SKGServices::stringToDouble ( listTmp.at ( 1 ).at ( 1 ) );
+            double v3=SKGServices::stringToDouble ( listTmp.at ( 1 ).at ( 2 ) );
+            QString s1=doc->formatMoney ( v1, primary );
+            QString s2=doc->formatMoney ( v2, primary );
+            QString s3=doc->formatMoney ( v3, primary );
+            ui.kInfo->setText ( i18nc ( "Message", "Balance: %1     Cleared: %2     In Transit: %3", s1, s2, s3 ) );
 
-	    SKGServices::SKGUnitInfo secondaryUnit=doc->getSecondaryUnit();
-	    if ( !secondaryUnit.Name.isEmpty() && secondaryUnit.Value )
-	    {
-		s1=doc->formatMoney ( v1, secondaryUnit );
-		s2=doc->formatMoney ( v2, secondaryUnit );
-		s3=doc->formatMoney ( v3, secondaryUnit );
-	    }
-	    ui.kInfo->setToolTip ( i18nc ("Message", "<p>Balance: %1</p><p>Cleared: %2</p><p>In Transit: %3</p>", s1, s2, s3 ) );
-	}
+            SKGServices::SKGUnitInfo secondaryUnit=doc->getSecondaryUnit();
+            if ( !secondaryUnit.Symbol.isEmpty() && secondaryUnit.Value )
+            {
+                s1=doc->formatMoney ( v1, secondaryUnit );
+                s2=doc->formatMoney ( v2, secondaryUnit );
+                s3=doc->formatMoney ( v3, secondaryUnit );
+            }
+            ui.kInfo->setToolTip ( i18nc ( "Message", "<p>Balance: %1</p><p>Cleared: %2</p><p>In Transit: %3</p>", s1, s2, s3 ) );
+        }
     }
 }
 
@@ -663,4 +713,21 @@ QWidget* SKGBankPluginWidget::getWidgetForPrint()
 {
     return ui.kAccountTableViewEdition;
 }
+
+void SKGBankPluginWidget::activateEditor()
+{
+    if (getCurrentMode()==-1) setCurrentMode(0);
+    ui.kAccountCreatorBank->setFocus();
+}
+
+bool SKGBankPluginWidget::isEditor()
+{
+    return true;
+}
+
+QWidget* SKGBankPluginWidget::zoomableWidget() const
+{
+    return ui.kAccountTableViewEdition;
+}
+
 #include "skgbankpluginwidget.moc"
