@@ -87,6 +87,24 @@ public:
      */
     virtual QWidget* getWidgetForPrint();
 
+    /**
+     * To know if this page contains an editor. MUST BE OVERWRITTEN
+     * @return the editor state
+     */
+    virtual bool isEditor();
+
+    /**
+     * To activate the editor by setting focus on right widget. MUST BE OVERWRITTEN
+     */
+    virtual void activateEditor();
+
+    /**
+     * Get the zoomable widget. MUST BE OVERWRITTEN
+     * By Overwritting this function, you don't have to implement following ones.
+     * @return the tree view.
+     */
+    virtual QWidget* zoomableWidget() const;
+
 protected:
     /**
      * Event filtering
