@@ -40,7 +40,7 @@
  */
 #define REFUNDINDEX 3
 
-SKGSplitTableDelegate::SKGSplitTableDelegate ( QObject* parent, const SKGDocument* iDoc ) : QItemDelegate ( parent ), document ( ( SKGDocument* ) iDoc ) {}
+SKGSplitTableDelegate::SKGSplitTableDelegate ( QObject* parent, SKGDocument* iDoc ) : QItemDelegate ( parent ), document ( iDoc ) {}
 
 SKGSplitTableDelegate::~SKGSplitTableDelegate()
 {
@@ -91,7 +91,7 @@ void SKGSplitTableDelegate::setEditorData ( QWidget* editor, const QModelIndex&
     if ( index.column() == AMOUNTINDEX )
     {
         SKGCalculatorEdit *calculator = static_cast<SKGCalculatorEdit*> ( editor );
-        if(calculator) calculator->setText ( index.model()->data ( index,Qt::EditRole ).toString() );
+        if (calculator) calculator->setText ( index.model()->data ( index,Qt::EditRole ).toString() );
     }
     else
     {
@@ -105,7 +105,7 @@ void SKGSplitTableDelegate::setModelData ( QWidget* editor, QAbstractItemModel*
     if ( index.column() == AMOUNTINDEX )
     {
         SKGCalculatorEdit *calculator = static_cast<SKGCalculatorEdit*> ( editor );
-        if(calculator && model) model->setData ( index,calculator->text(),Qt::EditRole );
+        if (calculator && model) model->setData ( index,calculator->text(),Qt::EditRole );
     }
     else
     {
