@@ -46,6 +46,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget ( SKGDocument* iDocument )
     //Add Standard KDE Icons to buttons
     ui.kUpdate->setIcon ( KIcon ( "dialog-ok-apply" ) );
     ui.kAdd->setIcon ( KIcon ( "list-add" ) );
+    ui.kSearch->setIcon ( KIcon ( "edit-find" ) );
 
     ui.kTopBtn->setIcon ( KIcon ( "arrow-up-double" ) );
     ui.kUpBtn->setIcon ( KIcon ( "arrow-up" ) );
@@ -62,15 +63,25 @@ SKGSearchPluginWidget::SKGSearchPluginWidget ( SKGDocument* iDocument )
 
     //Fill combo boxes
     QStringList attributeForQuery;
-    attributeForQuery << "d_date" << "i_number" << "t_mode" << "t_payee" << "t_comment" << "t_REALCATEGORY" << "t_status" << "t_bookmarked" << "t_imported" << "t_ACCOUNT" << "f_REALCURRENTAMOUNT" << "t_REFUND";
-    ui.kQueryCreator->setParameters ( iDocument, "v_operation_consolidated", attributeForQuery );
-
+    attributeForQuery << "d_date" << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_REALCATEGORY" << "t_status" << "t_bookmarked" << "t_imported" << "t_ACCOUNT" << "f_REALCURRENTAMOUNT" << "t_REALREFUND" << "f_BALANCE";
     QStringList attributeForUpdate;
-    attributeForUpdate << "i_number" << "t_mode" << "t_payee" << "t_comment" << "t_status" << "t_bookmarked" << "t_imported"<< "t_REALCATEGORY"<< "t_ACCOUNT" << "t_REFUND";
+    attributeForUpdate << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_status" << "t_bookmarked" << "t_imported"<< "t_REALCATEGORY"<< "t_ACCOUNT" << "t_REALREFUND";
+
+    //Adding properties
+    QStringList properties;
+    SKGServices::getDistinctValues(iDocument, "parameters", "t_name", "t_uuid_parent like '%-operation'", properties);
+    int nb=properties.count();
+    for (int i=0; i<nb; ++i)
+    {
+        attributeForQuery.push_back("p_"+properties.at(i));
+        attributeForUpdate.push_back("p_"+properties.at(i));
+    }
+
+    ui.kQueryCreator->setParameters ( iDocument, "v_operation_consolidated", attributeForQuery );
     ui.kActionCreator->setParameters ( iDocument, "v_operation_consolidated", attributeForUpdate, true );
 
     //Bind operation view
-    objectModel = new SKGObjectModel ( ( SKGDocumentBank* ) getDocument(), "v_rule", "1=1 ORDER BY f_sortorder", this, "", false );
+    objectModel = new SKGObjectModel ( static_cast<SKGDocumentBank*>(getDocument()), "v_rule", "1=1 ORDER BY f_sortorder", this, "", false );
 
     SKGSortFilterProxyModel* modelproxy = new SKGSortFilterProxyModel ( this );
     modelproxy->setSourceModel ( objectModel );
@@ -84,37 +95,25 @@ SKGSearchPluginWidget::SKGSearchPluginWidget ( SKGDocument* iDocument )
     //Add registered global action in contextual menu
     if ( SKGMainPanel::getMainPanel() )
     {
-        ui.kView->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "edit_delete" ) );
-        {
-            QAction* sep=new QAction ( this );
-            sep->setSeparator ( true );
-            ui.kView->insertAction ( 0, sep );
-        }
-        ui.kView->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "edit_switch_highlight" ) );
-        {
-            QAction* sep=new QAction ( this );
-            sep->setSeparator ( true );
-            ui.kView->insertAction ( 0, sep );
-        }
-        ui.kView->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "open_report" ) );
-        {
-            QAction* sep=new QAction ( this );
-            sep->setSeparator ( true );
-            ui.kView->insertAction ( 0, sep );
-        }
-        ui.kView->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "execute_all" ) );
-        ui.kView->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "execute_imported" ) );
-        ui.kView->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "execute_not_validated" ) );
+        ui.kView->insertGlobalAction ( "edit_delete" );
+        ui.kView->insertGlobalAction ();
+        ui.kView->insertGlobalAction ( "edit_switch_highlight" );
+        ui.kView->insertGlobalAction ();
+        ui.kView->insertGlobalAction ( "open_report" );
+        ui.kView->insertGlobalAction ();
+        ui.kView->insertGlobalAction ( "execute_all" );
+        ui.kView->insertGlobalAction ( "execute_imported" );
+        ui.kView->insertGlobalAction ( "execute_not_validated" );
 
-	KMenu* menu=new KMenu ( this );
-	menu->setIcon ( KIcon("system-run" ));
-	menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction ( "execute_all" ));
-	menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction ( "execute_imported" ));
-	menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction ( "execute_not_validated" ));
+        KMenu* menu=new KMenu ( this );
+        menu->setIcon ( KIcon("system-run" ));
+        menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction ( "execute_all" ));
+        menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction ( "execute_imported" ));
+        menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction ( "execute_not_validated" ));
 
-	ui.kApply->setIcon ( menu->icon() );
-	ui.kApply->setMenu ( menu );
-	ui.kApply->setPopupMode ( QToolButton::InstantPopup );
+        ui.kApply->setIcon ( menu->icon() );
+        ui.kApply->setMenu ( menu );
+        ui.kApply->setPopupMode ( QToolButton::InstantPopup );
     }
 
     setCurrentMode(0);
@@ -187,6 +186,8 @@ void SKGSearchPluginWidget::setState ( const QString& iState )
     if ( !filter.isEmpty() ) ui.kFilterEdit->setText ( filter );
     QString currentPage=root.attribute ( "currentPage" );
     if ( !currentPage.isEmpty() ) setCurrentMode ( SKGServices::stringToInt ( currentPage ) );
+    QString xmlsearchcondition=root.attribute ( "xmlsearchcondition" );
+    if ( !xmlsearchcondition.isEmpty() ) ui.kQueryCreator->setXMLCondition ( xmlsearchcondition );
 
     ui.kView->setState ( root.attribute ( "view" ) );
 }
@@ -201,7 +202,7 @@ void SKGSearchPluginWidget::onBtnModeClicked()
     QWidget* sender=static_cast<QWidget*> ( this->sender() );
 
     int currentMode=getCurrentMode();
-   int newMode=0;
+    int newMode=0;
 
     if ( sender==ui.kQueryBtn ) newMode=0;
 
@@ -213,17 +214,12 @@ void SKGSearchPluginWidget::setCurrentMode ( int iMode )
 {
     mode=iMode;
 
-    ui.kQueryGrp->hide();
-    ui.kActionGrp->hide();
+    ui.kQueryGrp->setVisible ( mode==0 );
     ui.kBtnFrm->setVisible ( mode==0 );
+    ui.typeSelection->setVisible ( mode==0 );
+    ui.kQueryBtn->setChecked ( mode==0 );
 
-    ui.kQueryBtn->setChecked ( false );
-
-    if ( mode==0 )
-    {
-        ui.kQueryGrp->show();
-        ui.kActionGrp->show();
-    }
+    onActionTypeChanged();
 
     onEditorModified();
 }
@@ -262,7 +258,7 @@ void SKGSearchPluginWidget::dataModified ( const QString& iTableName, int iIdTra
     if ( iTableName=="rule" || iTableName=="operation" || iTableName.isEmpty() )
     {
         //Correction bug 2299394 vvv
-        if ( ui.kView->isAutoResized() ) ui.kView->resizeColumnsToContents();
+        if ( ui.kView->isAutoResized() ) ui.kView->resizeColumnsToContentsDelayed();
         //Correction bug 2299394 ^^^
 
         //Correction 215658: vvv because the table is modified, the selection is modified
@@ -270,7 +266,7 @@ void SKGSearchPluginWidget::dataModified ( const QString& iTableName, int iIdTra
         //Correction 215658: ^^^
     }
 
-    ui.kAlarmUnit->setText ( ( ( SKGDocumentBank* ) getDocument() )->getPrimaryUnit().Name );
+    ui.kAlarmUnit->setText ( static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit().Symbol );
 }
 
 void SKGSearchPluginWidget::onAddRule()
@@ -306,6 +302,26 @@ void SKGSearchPluginWidget::onAddRule()
     SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
 }
 
+void SKGSearchPluginWidget::onSearch()
+{
+    SKGError err;
+    SKGTRACEINRC ( 1, "SKGSearchPluginWidget::onSearch", err );
+    SKGRuleObject rule;
+    QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
+    rule=SKGRuleObject ( getDocument() );
+    if ( err.isSucceeded() ) err=rule.setXMLSearchDefinition ( ui.kQueryCreator->getXMLCondition() );
+    if ( err.isSucceeded() ) err=rule.setOrder ( -1 );
+
+    QString xml=getXMLActionDefinition();
+    if ( err.isSucceeded() ) err=rule.setActionType ( xml.isEmpty() ? SKGRuleObject::SEARCH : SKGRuleObject::ActionType ( ui.kProcessType->currentIndex() ) );
+    if ( err.isSucceeded() ) err=rule.setXMLActionDefinition ( xml );
+    if ( err.isSucceeded() ) open(rule);
+    QApplication::restoreOverrideCursor();
+
+    //Display error
+    SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
+}
+
 void SKGSearchPluginWidget::onModifyRule()
 {
     SKGError err;
@@ -378,8 +394,8 @@ void SKGSearchPluginWidget::onSelectionChanged()
 
 void SKGSearchPluginWidget::onActionTypeChanged()
 {
-    ui.kAlarmFrm->setVisible ( ui.kProcessType->currentIndex() ==2 );
-    ui.kActionCreator->setVisible ( ui.kProcessType->currentIndex() ==1 );
+    ui.kAlarmFrm->setVisible ( mode == 0 && ui.kProcessType->currentIndex() ==2 );
+    ui.kActionGrp->setVisible ( mode == 0 && ui.kProcessType->currentIndex() ==1 );
 }
 
 void SKGSearchPluginWidget::onTop()
@@ -546,6 +562,47 @@ void SKGSearchPluginWidget::onBottom()
     SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
 }
 
+void SKGSearchPluginWidget::open(const SKGRuleObject& iRule) const
+{
+    _SKGTRACEIN ( 10, "SKGSearchPluginWidget::open" );
+
+    //Build where clause and title
+    QString wc="i_SUBOPID in (SELECT i_SUBOPID FROM v_operation_prop WHERE "+iRule.getSelectSqlOrder ()+')';
+    QString title=i18nc("Noun, a list of items", "Sub operations corresponding to rule '%1'",  iRule.getSearchDescription() );
+
+    //Open
+    if ( QApplication::keyboardModifiers() &Qt::ControlModifier && QApplication::keyboardModifiers() &Qt::ShiftModifier )
+    {
+        //Call debug plugin
+        QDomDocument doc ( "SKGML" );
+        QDomElement root = doc.createElement ( "parameters" );
+        doc.appendChild ( root );
+        root.setAttribute ( "sqlOrder", "SELECT * from v_operation_consolidated WHERE "+wc );
+
+        SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Debug plugin" ), -1, doc.toString() );
+    }
+    else
+    {
+        //Call operation plugin
+        QDomDocument doc ( "SKGML" );
+        doc.setContent ( getDocument()->getParameter ( "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS" ) );
+        QDomElement root = doc.documentElement();
+        if ( root.isNull() )
+        {
+            root=doc.createElement ( "parameters" );
+            doc.appendChild ( root );
+        }
+
+        root.setAttribute ( "operationTable", "v_operation_consolidated" );
+        root.setAttribute ( "operationWhereClause", wc );
+        root.setAttribute ( "title", title );
+        root.setAttribute ( "title_icon", "edit-find" );
+        root.setAttribute ( "currentPage", "-1" );
+
+        SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
+    }
+}
+
 void SKGSearchPluginWidget::onDoubleClick()
 {
     _SKGTRACEIN ( 10, "SKGSearchPluginWidget::onDoubleClick" );
@@ -555,42 +612,7 @@ void SKGSearchPluginWidget::onDoubleClick()
     if ( selection.count() ==1 )
     {
         SKGRuleObject rule ( selection.at ( 0 ) );
-
-        //Build where clause and title
-        QString wc=rule.getSelectSqlOrder ();
-        QString title=i18nc("Noun, a list of items", "Sub operations corresponding to rule '%1'",  rule.getSearchDescription() );
-
-        //Open
-        if ( QApplication::keyboardModifiers() &Qt::ControlModifier && QApplication::keyboardModifiers() &Qt::ShiftModifier )
-        {
-            //Call debug plugin
-            QDomDocument doc ( "SKGML" );
-            QDomElement root = doc.createElement ( "parameters" );
-            doc.appendChild ( root );
-            root.setAttribute ( "sqlOrder", "SELECT * from v_operation_consolidated WHERE "+wc );
-
-            SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge debug plugin" ), -1, doc.toString() );
-        }
-        else
-        {
-            //Call operation plugin
-            QDomDocument doc ( "SKGML" );
-            doc.setContent ( getDocument()->getParameter ( "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS" ) );
-            QDomElement root = doc.documentElement();
-            if ( root.isNull() )
-            {
-                root=doc.createElement ( "parameters" );
-                doc.appendChild ( root );
-            }
-
-            root.setAttribute ( "operationTable", "v_operation_consolidated" );
-            root.setAttribute ( "operationWhereClause", wc );
-            root.setAttribute ( "title", title );
-            root.setAttribute ( "title_icon", "edit-find" );
-            root.setAttribute ( "currentPage", "-1" );
-
-            SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
-        }
+        open(rule);
     }
 }
 
@@ -599,7 +621,10 @@ void SKGSearchPluginWidget::onEditorModified()
     SKGObjectBase::SKGListSKGObjectBase selection=getSelectedObjects();
     int nbSelect=selection.count();
 
-    ui.kUpdate->setEnabled ( nbSelect==1 );
+    bool activated=mode!=-1;
+
+    ui.kAdd->setEnabled ( activated );
+    ui.kUpdate->setEnabled ( activated && nbSelect==1 );
     ui.kQueryInfo->setText ( "" );
 
     if ( nbSelect==1 )
@@ -610,16 +635,16 @@ void SKGSearchPluginWidget::onEditorModified()
         QString wc=rule.getSelectSqlOrder ();
 
         SKGStringListList result;
-	int vAll=0;
-        SKGServices::executeSelectSqliteOrder ( getDocument(), "SELECT count(1) from v_operation_consolidated WHERE "+wc, result );
+        int vAll=0;
+        SKGServices::executeSelectSqliteOrder ( getDocument(), "SELECT count(distinct(id)) from v_operation_prop WHERE "+wc, result );
         if ( result.count() ==2 ) vAll=SKGServices::stringToInt ( result.at ( 1 ).at ( 0 ) );
 
-	int vImported=0;
-        SKGServices::executeSelectSqliteOrder ( getDocument(), "SELECT count(1) from v_operation_consolidated WHERE t_imported!='N' AND "+wc, result );
+        int vImported=0;
+        SKGServices::executeSelectSqliteOrder ( getDocument(), "SELECT count(distinct(id)) from v_operation_prop WHERE t_imported!='N' AND "+wc, result );
         if ( result.count() ==2 ) vImported=SKGServices::stringToInt ( result.at ( 1 ).at ( 0 ) );
 
-	int vNotValidatedl=0;
-        SKGServices::executeSelectSqliteOrder ( getDocument(), "SELECT count(1) from v_operation_consolidated WHERE t_imported='P' AND "+wc, result );
+        int vNotValidatedl=0;
+        SKGServices::executeSelectSqliteOrder ( getDocument(), "SELECT count(distinct(id)) from v_operation_prop WHERE t_imported='P' AND "+wc, result );
         if ( result.count() ==2 ) vNotValidatedl=SKGServices::stringToInt ( result.at ( 1 ).at ( 0 ) );
 
         ui.kQueryInfo->setText ( i18np ( "%1 operation found (%2 imported, %3 not yet validated).", "%1 operations found (%2 imported, %3 not yet validated).", vAll, vImported, vNotValidatedl) );
@@ -640,12 +665,12 @@ QString SKGSearchPluginWidget::getXMLActionDefinition()
     QString output;
     if ( ui.kProcessType->currentIndex() ==1 )
     {
-	//Mode update
+        //Mode update
         output=ui.kActionCreator->getXMLCondition();
     }
     else if ( ui.kProcessType->currentIndex() ==2 )
     {
-	//Mode alarm
+        //Mode alarm
         QDomDocument doc ( "SKGML" );
         QDomElement element = doc.createElement ( "element" );
         doc.appendChild ( element );
@@ -666,6 +691,21 @@ QString SKGSearchPluginWidget::getXMLActionDefinition()
     }
     return output;
 }
+
+bool SKGSearchPluginWidget::isEditor()
+{
+    return true;
+}
+
+void SKGSearchPluginWidget::activateEditor()
+{
+    if (getCurrentMode()==-1) setCurrentMode(0);
+}
+
+QWidget* SKGSearchPluginWidget::zoomableWidget() const
+{
+    return ui.kView;
+}
 #include "skgsearchpluginwidget.moc"
 
 
