@@ -23,6 +23,7 @@
 */
 #include "ui_skgsearchpluginwidget_base.h"
 #include "skgtabpage.h"
+#include "skgruleobject.h"
 
 class SKGObjectModel;
 
@@ -84,6 +85,24 @@ public:
      */
     virtual QWidget* getWidgetForPrint();
 
+    /**
+     * To know if this page contains an editor. MUST BE OVERWRITTEN
+     * @return the editor state
+     */
+    virtual bool isEditor();
+
+    /**
+     * To activate the editor by setting focus on right widget. MUST BE OVERWRITTEN
+     */
+    virtual void activateEditor();
+
+    /**
+     * Get the zoomable widget. MUST BE OVERWRITTEN
+     * By Overwritting this function, you don't have to implement following ones.
+     * @return the tree view.
+     */
+    virtual QWidget* zoomableWidget() const;
+
 protected:
     /**
      * Event filtering
@@ -97,6 +116,7 @@ private slots:
     void dataModified ( const QString& iTableName, int iIdTransaction );
     void onAddRule();
     void onModifyRule();
+    void onSearch();
     void onSelectionChanged();
     void onActionTypeChanged();
     void onTop();
@@ -114,6 +134,7 @@ private:
     QString getXMLActionDefinition();
     int getCurrentMode();
     void setCurrentMode ( int iMode );
+    void open(const SKGRuleObject& iRule) const;
 
     SKGObjectModel* objectModel;
     int mode;
