@@ -23,6 +23,7 @@
 #include "skgtrackerpluginwidget.h"
 #include "skgtracker_settings.h"
 #include "skgtraces.h"
+#include "skgdocumentbank.h"
 
 #include <kactioncollection.h>
 #include <kstandardaction.h>
@@ -38,89 +39,91 @@ K_EXPORT_PLUGIN(SKGTrackerPluginFactory("skrooge_tracker", "skrooge_tracker"))
 
 SKGTrackerPlugin::SKGTrackerPlugin(QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent)
 {
-        SKGTRACEIN(10, "SKGTrackerPlugin::SKGTrackerPlugin");
+    SKGTRACEIN(10, "SKGTrackerPlugin::SKGTrackerPlugin");
 }
 
 SKGTrackerPlugin::~SKGTrackerPlugin()
 {
-        SKGTRACEIN(10, "SKGTrackerPlugin::~SKGTrackerPlugin");
-        currentBankDocument=NULL;
+    SKGTRACEIN(10, "SKGTrackerPlugin::~SKGTrackerPlugin");
+    currentBankDocument=NULL;
 }
 
-void SKGTrackerPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
+bool SKGTrackerPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-        SKGTRACEIN(10, "SKGTrackerPlugin::setupActions");
-        Q_UNUSED(iArgument);
+    SKGTRACEIN(10, "SKGTrackerPlugin::setupActions");
+    Q_UNUSED(iArgument);
+    if (dynamic_cast<SKGDocumentBank*>(iDocument)==NULL) return false;
 
-        currentBankDocument=iDocument;
+    currentBankDocument=iDocument;
 
 
-        setComponentData( SKGTrackerPluginFactory::componentData() );
-        setXMLFile("skrooge_tracker.rc");
+    setComponentData( SKGTrackerPluginFactory::componentData() );
+    setXMLFile("skrooge_tracker.rc");
 
-        //Create yours actions here
+    //Create yours actions here
+    return true;
 }
 
 void SKGTrackerPlugin::refresh()
 {
-        SKGTRACEIN(10, "SKGTrackerPlugin::refresh");
+    SKGTRACEIN(10, "SKGTrackerPlugin::refresh");
 }
 
 void SKGTrackerPlugin::close()
 {
-        SKGTRACEIN(10, "SKGTrackerPlugin::close");
+    SKGTRACEIN(10, "SKGTrackerPlugin::close");
 }
 
 SKGTabPage* SKGTrackerPlugin::getWidget()
 {
-        SKGTRACEIN(10, "SKGTrackerPlugin::getWidget");
-        return new SKGTrackerPluginWidget(currentBankDocument);
+    SKGTRACEIN(10, "SKGTrackerPlugin::getWidget");
+    return new SKGTrackerPluginWidget(currentBankDocument);
 }
 
 QWidget* SKGTrackerPlugin::getPreferenceWidget()
 {
-        SKGTRACEIN(10, "SKGTrackerPlugin::getPreferenceWidget");
-        //QWidget* widget=new QWidget();
-        //ui.setupUi(widget);
+    SKGTRACEIN(10, "SKGTrackerPlugin::getPreferenceWidget");
+    //QWidget* widget=new QWidget();
+    //ui.setupUi(widget);
 
-        return NULL;
+    return NULL;
 }
 
 KConfigSkeleton* SKGTrackerPlugin::getPreferenceSkeleton()
 {
-        return skgtracker_settings::self();
+    return skgtracker_settings::self();
 }
 
 QString SKGTrackerPlugin::title() const
 {
-        return i18nc("Noun, something that is used to track items","Trackers");
+    return i18nc("Noun, something that is used to track items","Trackers");
 }
 
 QString SKGTrackerPlugin::icon() const
 {
-        return "skrooge_tracker";
+    return "skrooge_tracker";
 }
 
 QString SKGTrackerPlugin::toolTip () const
 {
-        return i18nc("A tool tip", "Trackers management");
+    return i18nc("A tool tip", "Trackers management");
 }
 
 int SKGTrackerPlugin::getOrder() const
 {
-        return 25;
+    return 25;
 }
 
 QStringList SKGTrackerPlugin::tips() const
 {
-        QStringList output;
-        output.push_back(i18nc("Description of a tips", "<p>...you can follow your refunds by using a tracker.</p>"));
-        return output;
+    QStringList output;
+    output.push_back(i18nc("Description of a tips", "<p>...you can follow your refunds by using a tracker.</p>"));
+    return output;
 }
 
 bool SKGTrackerPlugin::isInContext() const
 {
-        return true;
+    return true;
 }
 
 #include "skgtrackerplugin.moc"
