@@ -44,6 +44,9 @@ SKGUnitPluginWidget::SKGUnitPluginWidget ( SKGDocumentBank* iDocument )
     SKGTRACEIN ( 10, "SKGUnitPluginWidget::SKGUnitPluginWidget" );
 
     ui.setupUi ( this );
+    ui.kUnitCreatorUnit->setDocument(iDocument);
+    ui.kUnitCreatorUnit->setWhereClauseCondition("t_type IN ('1','2','C')");
+
     //Add Standard KDE Icons to buttons to Accounts
     ui.kUnitAdd->setIcon ( KIcon ( "list-add" ) );
     ui.kUnitUpdate->setIcon ( KIcon ( "dialog-ok-apply" ) );
@@ -53,6 +56,9 @@ SKGUnitPluginWidget::SKGUnitPluginWidget ( SKGDocumentBank* iDocument )
     ui.kManualBtn->setIcon ( KIcon ( "user-properties" ) );
     ui.kValuesBtn->setIcon ( KIcon ( "skrooge_unit" ) );
 
+    //Fill combo box for currency
+    refreshUnitList();
+
     //Fill combo box for type
     ui.kTypeCreatorUnit->addItem ( i18nc ( "Noun", "Primary currency" ) );
     ui.kTypeCreatorUnit->addItem ( i18nc ( "Noun", "Secondary currency" ) );
@@ -61,12 +67,9 @@ SKGUnitPluginWidget::SKGUnitPluginWidget ( SKGDocumentBank* iDocument )
     ui.kTypeCreatorUnit->addItem ( i18nc ( "Noun, a financial index like the Dow Jones, NASDAQ, CAC40...","Index" ) );
     ui.kTypeCreatorUnit->addItem ( i18nc ( "Noun, a physical object like a house or a car","Object" ) );
 
-    //Fill combo box for currency
-    ui.kCurrencyList->addItems ( SKGUnitObject::getListofKnownCurrencies() );
-
     //Bind unit creation view
     {
-        objectModel = new SKGObjectModel ( ( SKGDocumentBank* ) getDocument(), "v_unit_display", "", this, "", false );
+        objectModel = new SKGObjectModel ( static_cast<SKGDocumentBank*>(getDocument()), "v_unit_display", "", this, "", false );
 
         QSortFilterProxyModel* modelProxy = new QSortFilterProxyModel ( this );
         modelProxy->setSourceModel ( objectModel );
@@ -79,13 +82,11 @@ SKGUnitPluginWidget::SKGUnitPluginWidget ( SKGDocumentBank* iDocument )
         //Add registered global action in contextual menu
         if ( SKGMainPanel::getMainPanel() )
         {
-            ui.kUnitTableViewEdition->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "edit_delete" ) );
-            QAction* sep=new QAction ( this );
-            sep->setSeparator ( true );
-            ui.kUnitTableViewEdition->insertAction ( 0, sep );
-            ui.kUnitTableViewEdition->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "edit_split_stock" ) );
-            ui.kUnitTableViewEdition->insertAction ( 0, sep );
-            ui.kUnitTableViewEdition->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "open_report" ) );
+            ui.kUnitTableViewEdition->insertGlobalAction ( "edit_delete" );
+            ui.kUnitTableViewEdition->insertGlobalAction ();
+            ui.kUnitTableViewEdition->insertGlobalAction ( "edit_split_stock" );
+            ui.kUnitTableViewEdition->insertGlobalAction ();
+            ui.kUnitTableViewEdition->insertGlobalAction ( "open_report" );
         }
         connect ( ui.kUnitTableViewEdition, SIGNAL ( selectionChangedDelayed() ), this, SLOT ( onSelectionChanged() ) );
         connect ( objectModel, SIGNAL ( beforeReset() ), ui.kUnitTableViewEdition, SLOT ( saveSelection() ) );
@@ -94,12 +95,12 @@ SKGUnitPluginWidget::SKGUnitPluginWidget ( SKGDocumentBank* iDocument )
 
     //Bind unit creation view
     {
-        SKGObjectModel* objectModel2 = new SKGObjectModel ( ( SKGDocumentBank* ) getDocument(), "v_unitvalue_display", "1=0", this, "", false );
+        SKGObjectModel* objectModel2 = new SKGObjectModel ( static_cast<SKGDocumentBank*>(getDocument()), "v_unitvalue_display", "1=0", this, "", false );
 
         ui.kUnitValueTableViewEdition->setModel ( objectModel2 );
 
         //Add registered global action in contextual menu
-        if ( SKGMainPanel::getMainPanel() ) ui.kUnitValueTableViewEdition->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "edit_delete" ) );
+        ui.kUnitValueTableViewEdition->insertGlobalAction ( "edit_delete" );
 
         connect ( ui.kUnitValueTableViewEdition, SIGNAL ( selectionChangedDelayed() ), this, SLOT ( onSelectionValueChanged() ) );
     }
@@ -114,6 +115,9 @@ SKGUnitPluginWidget::SKGUnitPluginWidget ( SKGDocumentBank* iDocument )
     //Set Event filters to catch CTRL+ENTER or SHIFT+ENTER
     this->installEventFilter ( this );
 
+    //Synchronize zooms of both tables
+    connect ( ui.kUnitTableViewEdition, SIGNAL ( zoomChanged(int)), ui.kUnitValueTableViewEdition, SLOT ( setZoomPosition(int)) );
+    connect ( ui.kUnitValueTableViewEdition, SIGNAL ( zoomChanged(int)), ui.kUnitTableViewEdition, SLOT ( setZoomPosition(int)) );
 }
 
 SKGUnitPluginWidget::~SKGUnitPluginWidget()
@@ -178,7 +182,7 @@ void SKGUnitPluginWidget::onSelectionChanged()
 
         //Fill values
         QString wc="rd_unit_id=(select id from unit where t_name='"+SKGServices::stringToSqlString ( ui.kNameCreatorUnit->text() ) +"')";
-        SKGObjectModel* objectModel = ( SKGObjectModel* ) ui.kUnitValueTableViewEdition->model();
+        SKGObjectModel* objectModel = static_cast<SKGObjectModel*>(ui.kUnitValueTableViewEdition->model());
         if ( objectModel )
         {
             objectModel->setFilter ( "" ); //Correction 2299600: to be sure that refresh will be done
@@ -192,12 +196,12 @@ void SKGUnitPluginWidget::onSelectionChanged()
         SKGStringListList table;
         getDocument()->getConsolidatedView ( "v_unitvalue_display", "d_date", "t_UNIT", "f_quantity", "TOTAL", wc, table , "" );
 
-        SKGServices::SKGUnitInfo primaryUnit= ( ( SKGDocumentBank* ) getDocument() )->getPrimaryUnit();
-        SKGServices::SKGUnitInfo secondaryUnit= ( ( SKGDocumentBank* ) getDocument() )->getSecondaryUnit();
+        SKGServices::SKGUnitInfo primaryUnit= static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
+        SKGServices::SKGUnitInfo secondaryUnit= static_cast<SKGDocumentBank*>(getDocument())->getSecondaryUnit();
         ui.kGraph->setData ( table, primaryUnit, secondaryUnit, SKGTableWithGraph::LIMITS );
 
         //Correction bug 2299394 vvv
-        if ( ui.kUnitValueTableViewEdition->isAutoResized() ) ui.kUnitValueTableViewEdition->resizeColumnsToContents();
+        if ( ui.kUnitValueTableViewEdition->isAutoResized() ) ui.kUnitValueTableViewEdition->resizeColumnsToContentsDelayed();
         //Correction bug 2299394 ^^^
 
         onUnitCreatorModified();
@@ -218,13 +222,13 @@ void SKGUnitPluginWidget::onSelectionValueChanged()
         {
             QModelIndex idx=indexes[indexes.count()-1];
 
-            SKGObjectModel* model= ( SKGObjectModel* ) ui.kUnitValueTableViewEdition->model();
+            SKGObjectModel* model=static_cast<SKGObjectModel*>(ui.kUnitValueTableViewEdition->model());
             if ( model )
             {
                 SKGUnitValueObject unit ( model->getObject ( idx ) );
 
                 ui.kDateEdit->setDate ( unit.getDate() );
-                ui.kAmountEdit->setText ( unit.getAttribute ( "f_quantity" ) );
+                ui.kAmountEdit->setText ( KGlobal::locale()->formatMoney (SKGServices::stringToDouble(unit.getAttribute ( "f_quantity" )), "", 2) );
             }
         }
         else
@@ -292,7 +296,8 @@ void SKGUnitPluginWidget::onUnitCreatorModified()
 {
     SKGTRACEIN ( 10, "SKGUnitPluginWidget::onUnitCreatorModified" );
 
-    bool activated=ui.kNameCreatorUnit->text().length() >0 &&
+    bool activated=mode!=-1 &&
+                   ui.kNameCreatorUnit->text().length() >0 &&
                    ui.kSymbolCreatorUnit->text().length() >0;
 
     int nbSelect=getNbSelectedObjects();
@@ -314,16 +319,16 @@ void SKGUnitPluginWidget::onAddUnit()
     if ( mode==0 )
     {
         QString untiname=ui.kCurrencyList->text();
-        SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Unit creation [%1]", untiname ), err );
+        SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Unit creation '%1'", untiname ), err );
         SKGUnitObject oUnit;
-        err=SKGUnitObject::createCurrencyUnit ( ( SKGDocumentBank* ) getDocument(), ui.kCurrencyList->text(), oUnit );
+        err=SKGUnitObject::createCurrencyUnit ( static_cast<SKGDocumentBank*>(getDocument()), ui.kCurrencyList->text(), oUnit );
     }
     else if ( mode==1 )
     {
         QString untiname=ui.kNameCreatorUnit->text();
         SKGUnitObject unitObj ( getDocument() );
         {
-            SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Unit creation [%1]", untiname ), err );
+            SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Unit creation '%1'", untiname ), err );
 
             //Create unit object
             if ( err.isSucceeded() ) err=unitObj.setName ( untiname );
@@ -332,21 +337,14 @@ void SKGUnitPluginWidget::onAddUnit()
             if ( err.isSucceeded() ) err=unitObj.setInternetCode ( ui.kInternetCreatorUnit->text() );
             if ( err.isSucceeded() ) err=unitObj.setType ( ( SKGUnitObject::UnitType ) ( ui.kTypeCreatorUnit->currentIndex() ) );
             if ( err.isSucceeded() ) err=unitObj.setNumberDecimal ( ui.kNbDecimal->value() );
-            if ( err.isSucceeded() )
-            {
-                SKGUnitObject parent ( getDocument() );
-                if ( err.isSucceeded() ) err=parent.setSymbol ( ui.kUnitCreatorUnit->text() );
-                if ( err.isSucceeded() ) parent.load(); //Do not catch this error
-                if ( err.isSucceeded() && parent.exist() ) err=unitObj.setUnit ( parent );
-            }
-
+            if ( err.isSucceeded() ) err=unitObj.setUnit ( ui.kUnitCreatorUnit->getUnit() );
             if ( err.isSucceeded() ) err=unitObj.save();
         }
 
         //status bar
         if ( err.isSucceeded() )
         {
-            err=SKGError ( 0, i18nc ( "Successful message after an user action", "Unit [%1] created", untiname ) );
+            err=SKGError ( 0, i18nc ( "Successful message after an user action", "Unit '%1' created", untiname ) );
             ui.kUnitTableViewEdition->selectObject ( unitObj.getUniqueID() );
         }
         else err.addError ( ERR_FAIL, i18nc ( "Error message", "Unit creation failed" ) );
@@ -356,13 +354,13 @@ void SKGUnitPluginWidget::onAddUnit()
         QString untiname=ui.kNameCreatorUnit->text();
         SKGUnitValueObject unitValueObject;
         {
-            SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Unit value creation for [%1]", untiname ), err );
-            err= ( ( SKGDocumentBank* ) getDocument() )->addOrModifyUnitValue ( untiname, ui.kDateEdit->date(), ui.kAmountEdit->value(), &unitValueObject );
+            SKGBEGINTRANSACTION ( *getDocument(), i18nc ( "Noun, name of the user action", "Unit value creation for '%1'", untiname ), err );
+            err= static_cast<SKGDocumentBank*>(getDocument())->addOrModifyUnitValue ( untiname, ui.kDateEdit->date(), ui.kAmountEdit->value(), &unitValueObject );
         }
         //status bar
         if ( err.isSucceeded() )
         {
-            err=SKGError ( 0, i18nc ( "Successful message after an user action", "Unit value created for [%1]", untiname ) );
+            err=SKGError ( 0, i18nc ( "Successful message after an user action", "Unit value created for '%1'", untiname ) );
             //TODO doesn't work because of unit table is modified an refreshed ui.kUnitValueTableViewEdition->selectObject(unitValueObject.getUniqueID());
         }
         else err.addError ( ERR_FAIL, i18nc ( "Error message", "Unit value creation failed" ) );
@@ -386,7 +384,7 @@ void SKGUnitPluginWidget::onModifyUnit()
     int nb=selection.count();
     if ( nb )
     {
-        SKGBEGINPROGRESSTRANSACTION ( *getDocument(), ( nb==1 ? i18nc ( "Noun, name of the user action", "Unit [%1] update", ui.kNameCreatorUnit->text() ) : i18nc ( "Noun, name of the user action", "Updating %1 units.", nb ) )  , err, nb );
+        SKGBEGINPROGRESSTRANSACTION ( *getDocument(), ( nb==1 ? i18nc ( "Noun, name of the user action", "Unit '%1' update", ui.kNameCreatorUnit->text() ) : i18nc ( "Noun, name of the user action", "Updating %1 units.", nb ) )  , err, nb );
 
         for ( int i=0; err.isSucceeded() && i<nb; i++ )
         {
@@ -398,25 +396,13 @@ void SKGUnitPluginWidget::onModifyUnit()
             if ( err.isSucceeded() && nb==1 ) err=unitObj.setInternetCode ( ui.kInternetCreatorUnit->text() );
             if ( err.isSucceeded() ) err=unitObj.setType ( ( SKGUnitObject::UnitType ) ( ui.kTypeCreatorUnit->currentIndex() ) );
             if ( err.isSucceeded() ) err=unitObj.setNumberDecimal ( ui.kNbDecimal->value() );
-            QString parentName=ui.kUnitCreatorUnit->text();
-            if ( err.isSucceeded() )
-            {
-                if ( !parentName.isEmpty() )
-                {
-                    SKGUnitObject parent ( getDocument() );
-                    if ( err.isSucceeded() ) err=parent.setSymbol ( parentName );
-                    if ( err.isSucceeded() ) err=parent.load();
-                    if ( err.isSucceeded() && parent.exist() ) err=unitObj.setUnit ( parent );
-                }
-                else err=unitObj.removeUnit();
-            }
-
+            if ( err.isSucceeded() ) err=unitObj.setUnit ( ui.kUnitCreatorUnit->getUnit() );
             if ( err.isSucceeded() ) err=unitObj.save();
             if ( err.isSucceeded() ) err=getDocument()->stepForward ( i+1 );
         }
 
         //status bar
-        if ( err.isSucceeded() ) err=SKGError ( 0, ( nb==1 ? i18nc ( "Message for successful user action", "Unit [%1] updated", ui.kNameCreatorUnit->text() ) : i18nc ( "Message for successful user action","%1 units updated.", nb ) ) );
+        if ( err.isSucceeded() ) err=SKGError ( 0, ( nb==1 ? i18nc ( "Message for successful user action", "Unit '%1' updated", ui.kNameCreatorUnit->text() ) : i18nc ( "Message for successful user action","%1 units updated.", nb ) ) );
         else err.addError ( ERR_FAIL, i18nc ( "Error message", "Unit update failed" ) );
     }
     QApplication::restoreOverrideCursor();
@@ -449,7 +435,7 @@ void SKGUnitPluginWidget::onDoubleClickUnit()
             doc.appendChild ( root );
             root.setAttribute ( "sqlOrder", "SELECT * from v_operation_display WHERE "+wc );
 
-            SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge debug plugin" ), -1, doc.toString() );
+            SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Debug plugin" ), -1, doc.toString() );
         }
         else
         {
@@ -469,228 +455,31 @@ void SKGUnitPluginWidget::onDoubleClickUnit()
             root.setAttribute ( "title_icon", "skrooge_unit" );
             root.setAttribute ( "currentPage", "-1" );
 
-            SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
+            SKGMainPanel::getMainPanel()->openPage ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
         }
     }
 }
 
-SKGError SKGUnitPluginWidget::downloadUnitValue ( const SKGUnitObject& iUnit, UnitDownloadMode iMode )
+SKGError SKGUnitPluginWidget::downloadUnitValue (const SKGUnitObject& iUnit)
 {
     SKGError err;
     SKGTRACEINRC ( 10, "SKGUnitPluginWidget::downloadUnitValue",err );
+    SKGUnitObject::UnitDownloadMode mode;
+    if ( skgunit_settings::last() ) mode=SKGUnitObject::LAST;
+    else if ( skgunit_settings::last_monthly() ) mode=SKGUnitObject::LAST_MONTHLY;
+    else if ( skgunit_settings::last_weekly() )  mode=SKGUnitObject::LAST_WEEKLY;
+    else if ( skgunit_settings::last_daily() )   mode=SKGUnitObject::LAST_DAILY;
+    else if ( skgunit_settings::all_monthly() )  mode=SKGUnitObject::ALL_MONTHLY;
+    else if ( skgunit_settings::all_weekly() )   mode=SKGUnitObject::ALL_WEEKLY;
+    else if ( skgunit_settings::all_daily() )    mode=SKGUnitObject::ALL_DAILY;
 
     QString unitname=iUnit.getName();
     QString code=iUnit.getInternetCode();
-    SKGDocumentBank* doc= ( SKGDocumentBank* ) iUnit.getDocument();
+    SKGDocumentBank* doc=static_cast<SKGDocumentBank*>(iUnit.getDocument());
     if ( !code.isEmpty() && doc )
     {
-        bool invert=code.contains ( " /" );
-        code.remove ( " /" );
-        QString unitRef=doc->getPrimaryUnit().Name;
-        //BUG: 209905 vvvv
-        SKGUnitObject unitRefObj;
-        if ( iUnit.getUnit ( unitRefObj ).isSucceeded() )
-            unitRef=unitRefObj.getSymbol();
-        if ( unitRef==iUnit.getSymbol() ) unitRef="";
-        //BUG: 209905 ^^^^
         SKGBEGINTRANSACTION ( *doc, i18nc ( "Noun, name of the user action", "Download values for [%1 (%2)]", unitname, code ), err );
-
-        //Get last date
-        SKGStringListList result;
-        QString dateParameters;
-        SKGServices::executeSelectSqliteOrder ( doc, "SELECT MAX(d_date) FROM unitvalue where rd_unit_id=(SELECT id from unit where t_name='"+SKGServices::stringToSqlString ( unitname ) +"')",
-                                                result );
-        if ( result.count() ==2 )
-        {
-            QDate firstDate=SKGServices::stringToTime ( result.at ( 1 ).at ( 0 ) ).date();
-            dateParameters="a="+SKGServices::intToString ( firstDate.month()-1 ) +"&b="+SKGServices::intToString ( firstDate.day() ) +"&c="+SKGServices::intToString ( firstDate.year() );
-        }
-
-        //Example of code: DSY.PA
-        //http://ichart.yahoo.com/table.csv?s=DSY.PA&d=7&e=31&f=2008&g=d&a=0&b=1&c=2003&ignore=.csv
-        //&g=w = weekly
-        //&g=d = daily
-        //&g=m = monthly
-        QString parameters;
-        UnitDownloadMode mode=iMode;
-        if ( mode==AUTO )
-        {
-            if ( skgunit_settings::last() ) mode=LAST;
-            else if ( skgunit_settings::last_monthly() ) mode=LAST_MONTHLY;
-            else if ( skgunit_settings::last_weekly() )  mode=LAST_WEEKLY;
-            else if ( skgunit_settings::last_daily() )   mode=LAST_DAILY;
-            else if ( skgunit_settings::all_monthly() )  mode=ALL_MONTHLY;
-            else if ( skgunit_settings::all_weekly() )   mode=ALL_WEEKLY;
-            else if ( skgunit_settings::all_daily() )    mode=ALL_DAILY;
-        }
-
-        bool last= ( mode==LAST );
-        if ( last ) parameters=dateParameters+"&g=d";
-        else if ( mode==LAST_MONTHLY ) parameters=dateParameters+"&g=m";
-        else if ( mode==LAST_WEEKLY )  parameters=dateParameters+"&g=w";
-        else if ( mode==LAST_DAILY )   parameters=dateParameters+"&g=d";
-        else if ( mode==ALL_MONTHLY )  parameters="g=m";
-        else if ( mode==ALL_WEEKLY )   parameters="g=w";
-        else if ( mode==ALL_DAILY )    parameters="g=d";
-
-        //Download history
-        if ( !last )
-        {
-            QString path="http://ichart.yahoo.com/table.csv?s="+code+"&ignore=.csv&"+parameters;
-            KUrl url ( path );
-            QString tmpFile;
-            if ( KIO::NetAccess::download ( url, tmpFile, SKGMainPanel::getMainPanel() ) )
-            {
-
-                //Open file
-                QFile file ( tmpFile );
-                if ( !file.open ( QIODevice::ReadOnly | QIODevice::Text ) )
-                {
-                    doc->sendMessage ( i18nc ( "An information message", "Open file [%1] failed",tmpFile ) );
-                }
-                else
-                {
-                    QTextStream stream ( &file );
-
-                    //The file is something like this
-                    //Date,Open,High,Low,Close,Volume,Adj Close
-                    //2008-08-29,41.64,41.86,41.04,41.32,308800,41.32
-                    //2008-08-28,40.43,41.93,40.25,41.67,362000,41.67
-                    //2008-08-27,41.00,41.00,40.11,40.49,174200,40.49
-                    //2008-08-26,40.44,41.00,40.20,40.95,228200,40.95
-                    //2008-08-25,40.52,41.02,40.52,40.80,100100,40.80
-                    stream.readLine(); //to forget column names
-
-                    int nbLoaded=0;
-                    while ( !stream.atEnd() && err.isSucceeded() && nbLoaded<skgunit_settings::nb_loaded_values()-1 )  //-1 because the value of the day will be loaded after
-                    {
-                        //Read line
-                        QString line=stream.readLine().trimmed();
-                        QStringList fields=SKGServices::splitCSVLine ( line, ',' );
-                        if ( fields.count() ==7 )
-                        {
-                            QDate ds=QDate::fromString ( fields[0], "yyyy-MM-dd" );
-                            double val=SKGServices::stringToDouble ( fields[6] );
-                            double coef=1;
-                            if ( !unitRef.isEmpty() )
-                            {
-                                SKGUnitObject unitTmp ( doc );
-                                if ( err.isSucceeded() ) err=unitTmp.setSymbol ( unitRef );
-                                if ( err.isSucceeded() && unitTmp.exist() )
-                                {
-                                    err=unitTmp.load();
-                                    SKGUnitValueObject unitValTmp;
-                                    if ( err.isSucceeded() ) err=unitTmp.getUnitValue ( ds, unitValTmp );
-                                    //Correction: 2556409 vvv
-                                    if ( err.isFailed() )
-                                    {
-                                        err=SKGError ( 0, "" );
-                                        coef=1;
-                                    }
-                                    else coef=unitValTmp.getQuantity();
-                                    //Correction: 2556409 ^^^
-                                }
-                            }
-
-                            if ( err.isSucceeded() ) err=doc->addOrModifyUnitValue ( unitname, ds, coef* ( invert && val!=0 ? 1/val : val ) );
-                        }
-                        else
-                        {
-                            err.setReturnCode ( ERR_ABORT );
-                            err.setMessage ( i18nc ( "An error message", "Invalid line [%1] found in downloaded file.\nCheck this page: %2",line, path ) );
-                        }
-                        nbLoaded++;
-                    }
-
-                    //close file
-                    file.close();
-                }
-
-                //Remove tmp file
-                KIO::NetAccess::removeTempFile ( tmpFile );
-            }
-            else
-            {
-                doc->sendMessage ( KIO::NetAccess::lastErrorString() );
-            }
-        }
-        if ( err.isSucceeded() )
-        {
-            //http://download.finance.yahoo.com/d/quotes.csv?s=EURUSD=X&f=sl1d1t1c1ohgv&e=.csv
-            QString path="http://download.finance.yahoo.com/d/quotes.csv?s="+code+"&f=sl1d1t1c1ohgv&e=.csv";
-            KUrl url ( path );
-            QString tmpFile;
-            if ( KIO::NetAccess::download ( url, tmpFile, SKGMainPanel::getMainPanel() ) )
-            {
-
-                //Open file
-                QFile file ( tmpFile );
-                if ( !file.open ( QIODevice::ReadOnly | QIODevice::Text ) )
-                {
-                    doc->sendMessage ( i18nc ( "An information message", "Open file [%1] failed",tmpFile ) );
-                }
-                else
-                {
-                    QTextStream stream ( &file );
-
-                    //The file is something like this
-                    //"EURUSD=X",1.33,"10/20/2008","11:12am",N/A,N/A,N/A,N/A,N/A
-                    //"DSY.PA",32.46,"11/3/2008","9:56am",+0.13,32.00,32.50,31.21,360802
-
-                    //Read line
-                    QString line=stream.readLine().trimmed();
-                    line.remove ( '"' );
-                    QStringList fields=SKGServices::splitCSVLine ( line, ',' );
-                    QDate ds;
-                    if ( fields.count() >=5 && ( ds=QDate::fromString ( fields[2], "M/d/yyyy" ) ).isValid() )
-                    {
-                        double val=SKGServices::stringToDouble ( fields[1] );
-                        double coef=1;
-                        if ( !unitRef.isEmpty() )
-                        {
-                            SKGUnitObject unitTmp ( doc );
-                            if ( err.isSucceeded() ) err=unitTmp.setSymbol ( unitRef );
-                            if ( err.isSucceeded() && unitTmp.exist() )
-                            {
-                                err=unitTmp.load();
-                                SKGUnitValueObject unitValTmp;
-                                if ( err.isSucceeded() ) err=unitTmp.getUnitValue ( ds, unitValTmp );
-                                //Correction: 2556409 vvv
-                                if ( err.isFailed() )
-                                {
-                                    err=SKGError ( 0, "" );
-                                    coef=1;
-                                }
-                                else coef=unitValTmp.getQuantity();
-                                //Correction: 2556409 ^^^
-                            }
-                        }
-
-                        if ( err.isSucceeded() ) err=doc->addOrModifyUnitValue ( unitname, ds , coef* ( invert && val!=0 ? 1/val : val ) );
-                    }
-                    else
-                    {
-                        err.setReturnCode ( ERR_ABORT );
-                        err.setMessage ( i18nc ( "An error message", "Invalid line [%1] found in downloaded file.\nCheck this page: %2",line, path ) );
-                    }
-
-                    //close file
-                    file.close();
-                }
-
-                //Remove tmp file
-                KIO::NetAccess::removeTempFile ( tmpFile );
-            }
-            else
-            {
-                doc->sendMessage ( KIO::NetAccess::lastErrorString() );
-            }
-        }
-    }
-
-    if ( err.isFailed() )
-    {
-        err.addError ( ERR_FAIL, i18nc ( "Error message", "Impossible to download unit %1 with Internet code %2.", unitname, code ) );
+        err=iUnit.downloadUnitValue(mode, skgunit_settings::nb_loaded_values());
     }
 
     return err;
@@ -753,6 +542,7 @@ QString SKGUnitPluginWidget::getState()
     root.setAttribute ( "unitview", ui.kUnitTableViewEdition->getState() );
     root.setAttribute ( "unitvalueview", ui.kUnitValueTableViewEdition->getState() );
     root.setAttribute ( "currentPage", SKGServices::intToString ( getCurrentMode() ) );
+    root.setAttribute ( "obsolete", ui.kObsolete->isChecked() ? "Y" : "N" );
     root.setAttribute ( "graphSettings", ui.kGraph->getState() );
 
     return doc.toString();
@@ -773,6 +563,8 @@ void SKGUnitPluginWidget::setState ( const QString& iState )
     if ( !currentPage.isEmpty() ) setCurrentMode ( SKGServices::stringToInt ( currentPage ) );
     QString filter=root.attribute ( "filter" );
     if ( !filter.isEmpty() ) ui.kFilterEdit->setText ( filter );
+    QString obsolete=root.attribute ( "obsolete" );
+    if ( !obsolete.isEmpty() ) ui.kObsolete->setChecked(obsolete=="Y");
 
     ui.kUnitTableViewEdition->setState ( root.attribute ( "unitview" ) );
     ui.kUnitValueTableViewEdition->setState ( root.attribute ( "unitvalueview" ) );
@@ -796,18 +588,10 @@ void SKGUnitPluginWidget::dataModified ( const QString& iTableName, int iIdTrans
         setEnabled ( getDocument()->getDatabase() !=NULL );
 
         //Correction bug 2299394 vvv
-        if ( ui.kUnitTableViewEdition->isAutoResized() ) ui.kUnitTableViewEdition->resizeColumnsToContents();
-        if ( ui.kUnitValueTableViewEdition->isAutoResized() ) ui.kUnitValueTableViewEdition->resizeColumnsToContents();
+        if ( ui.kUnitTableViewEdition->isAutoResized() ) ui.kUnitTableViewEdition->resizeColumnsToContentsDelayed();
+        if ( ui.kUnitValueTableViewEdition->isAutoResized() ) ui.kUnitValueTableViewEdition->resizeColumnsToContentsDelayed();
         //Correction bug 2299394 ^^^
 
-        QStringList list;
-        SKGServices::getDistinctValues ( getDocument(), "unit", "ifnull(t_symbol,t_name)", "t_type IN ('1','2','C')", list );
-
-        //Fill combo
-        ui.kUnitCreatorUnit->clear();
-        list.insert ( 0, "" );
-        ui.kUnitCreatorUnit->addItems ( list );
-
         onSelectionChanged();
     }
 }
@@ -824,4 +608,26 @@ void SKGUnitPluginWidget::cleanEditor()
     }
 }
 
+bool SKGUnitPluginWidget::isEditor()
+{
+    return true;
+}
+
+void SKGUnitPluginWidget::activateEditor()
+{
+    if (getCurrentMode()==-1) setCurrentMode(0);
+    ui.kCurrencyList->setFocus();
+}
+
+void SKGUnitPluginWidget::refreshUnitList()
+{
+    ui.kCurrencyList->clear();
+    ui.kCurrencyList->addItems ( SKGUnitObject::getListofKnownCurrencies(ui.kObsolete->isChecked()) );
+}
+
+QWidget* SKGUnitPluginWidget::zoomableWidget() const
+{
+    return ui.kUnitTableViewEdition;
+}
+
 #include "skgunitpluginwidget.moc"
