@@ -39,19 +39,6 @@ class SKGUnitPluginWidget : public SKGTabPage
      */
     Q_ENUMS ( UnitDownloadMode );
 public:
-    /**
-     * This enumerate defines the mode of download
-     */
-    enum UnitDownloadMode {AUTO, 		/**< automatic mode (use setting)*/
-                           LAST, 		/**< last value only*/
-                           LAST_MONTHLY, 	/**< one value par month since last download*/
-                           LAST_WEEKLY, 	/**< one value par week since last download*/
-                           LAST_DAILY, 	/**< one value par day since last download*/
-                           ALL_MONTHLY, 	/**< one value par month*/
-                           ALL_WEEKLY, 	/**< one value par week*/
-                           ALL_DAILY 	/**< one value par day*/
-                          };
-
     /**
      * Default Constructor
      */
@@ -99,11 +86,28 @@ public:
     /**
      * Download values for a unit
      * @param iUnit unit
-     * @param iMode download mode
      * @return an object managing the error
      *   @see SKGError
      */
-    static SKGError downloadUnitValue ( const SKGUnitObject& iUnit, UnitDownloadMode iMode=AUTO );
+    static SKGError downloadUnitValue (const SKGUnitObject& iUnit);
+
+    /**
+     * To know if this page contains an editor. MUST BE OVERWRITTEN
+     * @return the editor state
+     */
+    virtual bool isEditor();
+
+    /**
+     * To activate the editor by setting focus on right widget. MUST BE OVERWRITTEN
+     */
+    virtual void activateEditor();
+
+    /**
+     * Get the zoomable widget. MUST BE OVERWRITTEN
+     * By Overwritting this function, you don't have to implement following ones.
+     * @return the tree view.
+     */
+    virtual QWidget* zoomableWidget() const;
 
 protected:
     /**
@@ -125,6 +129,7 @@ private slots:
     void onDoubleClickUnit();
     void onBtnModeClicked();
     void cleanEditor();
+    void refreshUnitList();
 
 private:
     Q_DISABLE_COPY ( SKGUnitPluginWidget );
